@@ -25,16 +25,13 @@
 
 #include "digikamview.moc"
 
-// Qt includes
-
-#include <QProcess>
-
 // KDE includes
 
 #include <kapplication.h>
 #include <kdebug.h>
 #include <kdialog.h>
 #include <kmessagebox.h>
+#include <ktoolinvocation.h>
 #include <krun.h>
 
 // Local includes
@@ -520,7 +517,7 @@ void DigikamView::setupConnections()
 
     connect(d->albumHistory, SIGNAL(signalSetSelectedUrls(KUrl::List)),
             d->iconView, SLOT(setSelectedUrls(KUrl::List)));
-            
+
     connect(d->albumManager, SIGNAL(signalAlbumDeleted(Album*)),
             d->albumHistory, SLOT(slotAlbumDeleted(Album*)));
 }
@@ -953,7 +950,7 @@ void DigikamView::slotAlbumSelected(Album* album)
         d->albumWidgetStack->setPreviewMode(AlbumWidgetStack::PreviewAlbumMode);
 }
 
-void DigikamView::slotAlbumOpenInKonqui()
+void DigikamView::slotAlbumOpenInFileManager()
 {
     Album *album = d->albumManager->currentAlbum();
     if (!album || album->type() != Album::PHYSICAL)
@@ -972,18 +969,24 @@ void DigikamView::slotAlbumOpenInTerminal()
 
     PAlbum* palbum = dynamic_cast<PAlbum*>(album);
 
-    const QString terminalApp("konsole");
-    QStringList args;
-    args << "--workdir" << palbum->folderPath();
-    const bool success = QProcess::startDetached(terminalApp, args);
-
-    if (!success)
+    if (!palbum)
     {
-        KMessageBox::error(this,
-            i18n("Cannot start the \"konsole\" application.\n"
-                 "Please make sure that it is installed and in your path."),
-            windowTitle()/*i18n("Open Album in Terminal")*/);
+        return;
     }
+
+    QString dir(palbum->folderPath());
+
+    // If the given directory is not local, it can still be the URL of an
+    // ioslave using UDS_LOCAL_PATH which to be converted first.
+    KUrl url = KIO::NetAccess::mostLocalUrl(dir, this);
+
+    //If the URL is local after the above conversion, set the directory.
+    if (url.isLocalFile())
+    {
+        dir = url.toLocalFile();
+    }
+
+    KToolInvocation::invokeTerminal(QString(), dir);
 }
 
 void DigikamView::slotAlbumRefresh()
@@ -1053,7 +1056,7 @@ double DigikamView::zoomMax()
 
 void DigikamView::setZoomFactor(double zoom)
 {
-    d->albumWidgetStack->setZoomFactorSnapped(zoom);    
+    d->albumWidgetStack->setZoomFactorSnapped(zoom);
 }
 
 void DigikamView::slotZoomFactorChanged(double zoom)
@@ -1433,6 +1436,10 @@ void DigikamView::slotSortImages(int sortRole)
 
 void DigikamView::slotSortImagesOrder(int order)
 {
+    AlbumSettings* settings = AlbumSettings::instance();
+    if (!settings)
+        return;
+    settings->setImageSorting(order);
     d->iconView->imageFilterModel()->setSortOrder((ImageSortSettings::SortOrder) order);
 }
 
@@ -1564,6 +1571,10 @@ void DigikamView::slideShow(const ImageInfoList& infoList)
          !d->cancelSlideShow && (it != infoList.constEnd()) ; ++it)
     {
         ImageInfo info = *it;
+        if (info.isNull() || info.category() != DatabaseItem::Image)
+        {
+            continue;
+        }
         settings.fileList.append(info.fileUrl());
         SlidePictureInfo pictInfo;
         pictInfo.comment   = info.comment();
