@@ -61,7 +61,7 @@
 namespace DigikamEnhanceImagePlugin
 {
 
-class LocalContrastToolPriv
+class LocalContrastTool::LocalContrastToolPriv
 {
 public:
 
@@ -158,18 +158,12 @@ void LocalContrastTool::slotResetSettings()
 
 void LocalContrastTool::prepareEffect()
 {
-    toolSettings()->setEnabled(false);
-    toolView()->setEnabled(false);
-
     DImg image = d->previewWidget->getOriginalRegionImage(true);
     setFilter(new LocalContrastFilter(&image, this, d->settingsView->settings()));
 }
 
 void LocalContrastTool::prepareFinal()
 {
-    toolSettings()->setEnabled(false);
-    toolView()->setEnabled(false);
-
     ImageIface iface(0, 0);
     setFilter(new LocalContrastFilter(iface.getOriginalImg(), this, d->settingsView->settings()));
 }
@@ -196,12 +190,6 @@ void LocalContrastTool::putFinalData()
     iface.putOriginalImage(i18n("Local Contrast"), filter()->getTargetImage().bits());
 }
 
-void LocalContrastTool::renderingFinished()
-{
-    toolSettings()->setEnabled(true);
-    toolView()->setEnabled(true);
-}
-
 void LocalContrastTool::slotLoadSettings()
 {
     d->settingsView->loadSettings();
