@@ -37,6 +37,7 @@
 #include <QFileInfo>
 #include <QStringList>
 #include <QSet>
+#include <QTime>
 
 // KDE includes
 
@@ -204,6 +205,9 @@ void CollectionScanner::setObserver(CollectionScannerObserver *observer)
 
 void CollectionScanner::completeScan()
 {
+    QTime time;
+    time.start();
+
     emit startCompleteScan();
 
     // lock database
@@ -275,6 +279,8 @@ void CollectionScanner::completeScan()
     markDatabaseAsScanned();
 
     emit finishedCompleteScan();
+
+    kDebug() << "Complete scan took:" << time.elapsed() << "msecs.";
 }
 
 void CollectionScanner::partialScan(const QString& filePath)
@@ -344,25 +350,25 @@ void CollectionScanner::partialScan(const QString& albumRoot, const QString& alb
     updateRemovedItemsTime();
 }
 
-void CollectionScanner::scanFile(const QString& filePath, FileScanMode mode)
+qlonglong CollectionScanner::scanFile(const QString& filePath, FileScanMode mode)
 {
     QFileInfo info(filePath);
     QString dirPath   = info.path(); // strip off filename
     QString albumRoot = CollectionManager::instance()->albumRootPath(dirPath);
 
     if (albumRoot.isNull())
-        return;
+        return -1;
 
     QString album = CollectionManager::instance()->album(dirPath);
-    scanFile(albumRoot, album, info.fileName(), mode);
+    return scanFile(albumRoot, album, info.fileName(), mode);
 }
 
-void CollectionScanner::scanFile(const QString& albumRoot, const QString& album, const QString& fileName, FileScanMode mode)
+qlonglong CollectionScanner::scanFile(const QString& albumRoot, const QString& album, const QString& fileName, FileScanMode mode)
 {
     if (album.isEmpty() || fileName.isEmpty())
     {
         kWarning() << "scanFile(QString, QString, QString) called with empty album or empty filename";
-        return;
+        return -1;
     }
 
     if (DatabaseAccess().backend()->isInTransaction())
@@ -370,7 +376,7 @@ void CollectionScanner::scanFile(const QString& albumRoot, const QString& album,
         // Install ScanController::instance()->suspendCollectionScan around your DatabaseTransaction
         kError() << "Detected an active database transaction when starting a collection file scan. "
                          "Please report this error.";
-        return;
+        return -1;
     }
 
     CollectionLocation location = CollectionManager::instance()->locationForAlbumRootPath(albumRoot);
@@ -378,7 +384,7 @@ void CollectionScanner::scanFile(const QString& albumRoot, const QString& album,
     if (location.isNull())
     {
         kWarning() << "Did not find a CollectionLocation for album root path " << albumRoot;
-        return;
+        return -1;
     }
 
     QDir dir(location.albumRootPath() + album);
@@ -387,7 +393,7 @@ void CollectionScanner::scanFile(const QString& albumRoot, const QString& album,
     if (!fi.exists())
     {
         kWarning() << "File given to scan does not exist" << albumRoot << album << fileName;
-        return;
+        return -1;
     }
 
     int albumId       = checkAlbum(location, album);
@@ -401,10 +407,10 @@ void CollectionScanner::scanFile(const QString& albumRoot, const QString& album,
         {
             case NormalScan:
             case ModifiedScan:
-                scanNewFile(fi, albumId);
+                imageId = scanNewFile(fi, albumId);
                 break;
             case Rescan:
-                scanNewFileFullScan(fi, albumId);
+                imageId = scanNewFileFullScan(fi, albumId);
                 break;
         }
     }
@@ -424,6 +430,8 @@ void CollectionScanner::scanFile(const QString& albumRoot, const QString& album,
                 break;
         }
     }
+
+    return imageId;
 }
 
 void CollectionScanner::scanFile(const ImageInfo& info, FileScanMode mode)
@@ -482,22 +490,24 @@ void CollectionScanner::scanAlbumRoot(const CollectionLocation& location)
 
 void CollectionScanner::scanForStaleAlbums(QList<CollectionLocation> locations)
 {
+    Q_UNUSED(locations);
     if (d->wantSignals)
         emit startScanningForStaleAlbums();
 
     QList<AlbumShortInfo> albumList = DatabaseAccess().db()->getAlbumShortInfos();
     QList<int> toBeDeleted;
 
+    /* see #231598
     QHash<int, CollectionLocation> albumRoots;
     foreach (const CollectionLocation& location, locations)
-        albumRoots[location.id()] = location;
+        albumRoots[location.id()] = location;*/
 
     QList<AlbumShortInfo>::const_iterator it;
     for (it = albumList.constBegin(); it != albumList.constEnd(); ++it)
     {
-        CollectionLocation location = albumRoots.value((*it).albumRootId);
+        CollectionLocation location = CollectionManager::instance()->locationForAlbumRootId((*it).albumRootId);
         // Only handle albums on available locations
-        if (!location.isNull())
+        if (location.isAvailable())
         {
             QFileInfo fileInfo(location.albumRootPath() + (*it).relativePath);
             if (!fileInfo.exists() || !fileInfo.isDir())
@@ -524,8 +534,8 @@ void CollectionScanner::scanForStaleAlbums(QList<CollectionLocation> locations)
             if (toBeDeletedIndex != -1)
             {
                 // check for existence of target
-                CollectionLocation location = albumRoots.value(it.key().albumRootId);
-                if (!location.isNull())
+                CollectionLocation location = CollectionManager::instance()->locationForAlbumRootId(it.key().albumRootId);
+                if (location.isAvailable())
                 {
                     QFileInfo fileInfo(location.albumRootPath() + it.key().relativePath);
                     if (fileInfo.exists() && fileInfo.isDir())
@@ -727,10 +737,14 @@ void CollectionScanner::scanFileNormal(const QFileInfo& fi, const ItemScanInfo&
                 scanModifiedFile(fi, scanInfo);
             }
         }
+        else if ((int)fi.size() != scanInfo.fileSize)
+        {
+            scanModifiedFile(fi, scanInfo);
+        }
     }
 }
 
-void CollectionScanner::scanNewFile(const QFileInfo& info, int albumId)
+qlonglong CollectionScanner::scanNewFile(const QFileInfo& info, int albumId)
 {
     ImageScanner scanner(info);
     scanner.setCategory(category(info));
@@ -753,13 +767,16 @@ void CollectionScanner::scanNewFile(const QFileInfo& info, int albumId)
             // Establishing identity with the unique hsah
             scanner.newFile(albumId);
     }
+
+    return scanner.id();
 }
 
-void CollectionScanner::scanNewFileFullScan(const QFileInfo& info, int albumId)
+qlonglong CollectionScanner::scanNewFileFullScan(const QFileInfo& info, int albumId)
 {
     ImageScanner scanner(info);
     scanner.setCategory(category(info));
     scanner.newFileFullScan(albumId);
+    return scanner.id();
 }
 
 void CollectionScanner::scanModifiedFile(const QFileInfo& info, const ItemScanInfo& scanInfo)
@@ -776,6 +793,14 @@ void CollectionScanner::rescanFile(const QFileInfo& info, const ItemScanInfo& sc
     scanner.rescan();
 }
 
+void CollectionScanner::copyFileProperties(const ImageInfo& source, const ImageInfo& dest)
+{
+    if (source.isNull() || dest.isNull())
+        return;
+
+    ImageScanner::copyProperties(source.id(), dest.id());
+}
+
 int CollectionScanner::countItemsInFolder(const QString& directory)
 {
     int items = 0;
