@@ -939,12 +939,11 @@ DColor DImg::getPixelColor(uint x, uint y) const
 {
     if (m_priv->null || x >= m_priv->width || y >= m_priv->height)
     {
-        kDebug() << "DImg::getPixelColor() : wrong pixel position!";
         return DColor();
     }
 
     int depth   = bytesDepth();
-    uchar *data = m_priv->data + x*depth + (m_priv->width*y*depth);
+    uchar* data = m_priv->data + x*depth + (m_priv->width*y*depth);
 
     return( DColor(data, m_priv->sixteenBit) );
 }
@@ -1010,11 +1009,10 @@ DColor DImg::getSubPixelColor(float x, float y) const
 {
     if (isNull() || x >= width() || y >= height())
     {
-        kDebug() << "DImg::getPixelColor() : wrong pixel position!";
         return DColor();
     }
 
-    const LANCZOS_DATA_TYPE *lanczos_func = m_priv->lanczos_func;
+    const LANCZOS_DATA_TYPE* lanczos_func = m_priv->lanczos_func;
     if (lanczos_func == 0)
         return DColor();
 
@@ -1169,18 +1167,16 @@ void DImg::setPixelColor(uint x, uint y, const DColor& color)
 {
     if (m_priv->null || x > m_priv->width || y > m_priv->height)
     {
-        kDebug() << "DImg::setPixelColor() : wrong pixel position!";
         return;
     }
 
     if (color.sixteenBit() != m_priv->sixteenBit)
     {
-        kDebug() << "DImg::setPixelColor() : wrong color depth!";
         return;
     }
 
     int depth   = bytesDepth();
-    uchar *data = m_priv->data + x*depth + (m_priv->width*y*depth);
+    uchar* data = m_priv->data + x*depth + (m_priv->width*y*depth);
     color.setPixel(data);
 }
 
@@ -2052,7 +2048,7 @@ void DImg::convertDepth(int depth)
         uint dim = width() * height() * 4;
         for (uint i = 0; i < dim; ++i)
         {
-            *dptr++ = (*sptr++ * 255UL) / 65535UL;
+            *dptr++ = (*sptr++ * 256UL) / 65536UL;
         }
 
         delete [] m_priv->data;
@@ -2067,10 +2063,31 @@ void DImg::convertDepth(int depth)
         ushort* dptr = (ushort*)data;
         uchar*  sptr = bits();
 
+        QDateTime dt = QDateTime::currentDateTime();
+        QDateTime Y2000( QDate(2000, 1, 1), QTime(0, 0, 0) );
+        uint seed = dt.secsTo(Y2000);
+#ifdef WIN32
+        srand(seed);
+#endif
+        ushort noise = 0;
+
         uint dim = width() * height() * 4;
         for (uint i = 0; i < dim; ++i)
         {
-            *dptr++ = (*sptr++ * 65535ULL) / 255ULL;
+            if (i % 4 < 3)
+            {
+#ifndef _WIN32
+                noise = (ushort)(256.0 * (rand_r(&seed) / (RAND_MAX + 1.0)));
+#else
+                noise = (ushort)(256.0 * (rand() / (RAND_MAX + 1.0)));
+#endif
+            }
+            else
+            {
+                noise = 0;
+            }
+
+            *dptr++ = (*sptr++ * 65536ULL) / 256ULL + noise;
         }
 
         delete [] m_priv->data;
