@@ -56,7 +56,7 @@ using namespace KDcrawIface;
 namespace Digikam
 {
 
-class MixerSettingsPriv
+class MixerSettings::MixerSettingsPriv
 {
 public:
 
@@ -364,6 +364,7 @@ void MixerSettings::slotMonochromeActived(bool mono)
 {
     d->mixerSettings.bMonochrome = d->monochrome->isChecked();
     emit signalMonochromeActived(mono);
+    emit signalSettingsChanged();
 }
 
 void MixerSettings::slotLuminosityChanged(bool)
@@ -379,9 +380,11 @@ MixerContainer MixerSettings::settings() const
 
 void MixerSettings::setSettings(const MixerContainer& settings)
 {
+    blockSignals(true);
     d->mixerSettings = settings;
     updateSettingsWidgets();
     slotMonochromeActived(d->mixerSettings.bMonochrome);
+    blockSignals(false);
 }
 
 void MixerSettings::resetToDefault()
