@@ -6,7 +6,7 @@
  * Date        : 2006-06-14
  * Description : A JPEG2000 IO file for DImg framework
  *
- * Copyright (C) 2006-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This implementation use Jasper API
  * library : http://www.ece.uvic.ca/~mdadams/jasper
@@ -36,20 +36,21 @@
 // files io. Uncomment this line only for debugging.
 //#define ENABLE_DEBUG_MESSAGES
 
-// Qt includes.
+// Qt includes
 
 #include <QFile>
 #include <QByteArray>
 #include <QTextStream>
 
-// KDE includes.
+// KDE includes
 
 #include <kdebug.h>
 
-// Local includes.
+// Local includes
 
 #include "dimg.h"
 #include "dimgloaderobserver.h"
+#include "dmetadata.h"
 #include "jp2kloader.h"
 
 namespace Digikam
@@ -91,6 +92,22 @@ bool JP2KLoader::load(const QString& filePath, DImgLoaderObserver *observer)
 
     fclose(file);
 
+    imageSetAttribute("format", "JP2K");
+    if (!(m_loadFlags & LoadImageData) && !(m_loadFlags & LoadICCData))
+    {
+        // libjasper will load the full image in memory already when calling jas_image_decode.
+        // This is bad when scanning. See bugs 215458 and 195583.
+        //FIXME: Use Exiv2 or OpenJPEG to extract this info
+        DMetadata metadata(filePath);
+        QSize size = metadata.getImageDimensions();
+        if (size.isValid())
+        {
+            imageWidth() = size.width();
+            imageHeight() = size.height();
+        }
+        return true;
+    }
+
     // -------------------------------------------------------------------
     // Initialize JPEG 2000 API.
 
@@ -106,14 +123,14 @@ bool JP2KLoader::load(const QString& filePath, DImgLoaderObserver *observer)
     int init = jas_init();
     if (init != 0)
     {
-        kDebug(50003) << "Unable to init JPEG2000 decoder" << endl;
+        kDebug() << "Unable to init JPEG2000 decoder";
         return false;
     }
 
     jp2_stream = jas_stream_fopen(QFile::encodeName(filePath), "rb");
     if (jp2_stream == 0)
     {
-        kDebug(50003) << "Unable to open JPEG2000 stream" << endl;
+        kDebug() << "Unable to open JPEG2000 stream";
         return false;
     }
 
@@ -121,7 +138,7 @@ bool JP2KLoader::load(const QString& filePath, DImgLoaderObserver *observer)
     if (jp2_image == 0)
     {
         jas_stream_close(jp2_stream);
-        kDebug(50003) << "Unable to decode JPEG2000 image" << endl;
+        kDebug() << "Unable to decode JPEG2000 image";
         return false;
     }
 
@@ -129,7 +146,7 @@ bool JP2KLoader::load(const QString& filePath, DImgLoaderObserver *observer)
 
     // some pseudo-progress
     if (observer)
-        observer->progressInfo(m_image, 0.1);
+        observer->progressInfo(m_image, 0.1F);
 
     // -------------------------------------------------------------------
     // Check color space.
@@ -145,7 +162,7 @@ bool JP2KLoader::load(const QString& filePath, DImgLoaderObserver *observer)
             if ((components[0] < 0) || (components[1] < 0) || (components[2] < 0))
             {
                 jas_image_destroy(jp2_image);
-                kDebug(50003) << "Error parsing JPEG2000 image : Missing Image Channel" << endl;
+                kDebug() << "Error parsing JPEG2000 image : Missing Image Channel";
                 return false;
             }
 
@@ -154,7 +171,7 @@ bool JP2KLoader::load(const QString& filePath, DImgLoaderObserver *observer)
             if (components[3] > 0)
             {
                 m_hasAlpha = true;
-                number_components++;
+                ++number_components;
             }
             colorModel = DImg::RGB;
             break;
@@ -165,7 +182,7 @@ bool JP2KLoader::load(const QString& filePath, DImgLoaderObserver *observer)
             if (components[0] < 0)
             {
                 jas_image_destroy(jp2_image);
-                kDebug(50003) << "Error parsing JP2000 image : Missing Image Channel" << endl;
+                kDebug() << "Error parsing JP2000 image : Missing Image Channel";
                 return false;
             }
             number_components = 1;
@@ -180,7 +197,7 @@ bool JP2KLoader::load(const QString& filePath, DImgLoaderObserver *observer)
             if ((components[0] < 0) || (components[1] < 0) || (components[2] < 0))
             {
                 jas_image_destroy(jp2_image);
-                kDebug(50003) << "Error parsing JP2000 image : Missing Image Channel" << endl;
+                kDebug() << "Error parsing JP2000 image : Missing Image Channel";
                 return false;
             }
             number_components = 3;
@@ -188,7 +205,7 @@ bool JP2KLoader::load(const QString& filePath, DImgLoaderObserver *observer)
             if (components[3] > 0)
             {
                 m_hasAlpha = true;
-                number_components++;
+                ++number_components;
             }
             // FIXME : image->colorspace=YCbCrColorspace;
             colorModel = DImg::YCBCR;
@@ -197,7 +214,7 @@ bool JP2KLoader::load(const QString& filePath, DImgLoaderObserver *observer)
         default:
         {
             jas_image_destroy(jp2_image);
-            kDebug(50003) << "Error parsing JP2000 image : Colorspace Model Is Not Supported" << endl;
+            kDebug() << "Error parsing JP2000 image : Colorspace Model Is Not Supported";
             return false;
         }
     }
@@ -208,7 +225,7 @@ bool JP2KLoader::load(const QString& filePath, DImgLoaderObserver *observer)
     imageWidth()  = jas_image_width(jp2_image);
     imageHeight() = jas_image_height(jp2_image);
 
-    for (i = 0; i < (long)number_components; i++)
+    for (i = 0; i < (long)number_components; ++i)
     {
         if ((((jas_image_cmptwidth(jp2_image, components[i])*
             jas_image_cmpthstep(jp2_image, components[i])) != (long)imageWidth()))  ||
@@ -219,7 +236,7 @@ bool JP2KLoader::load(const QString& filePath, DImgLoaderObserver *observer)
             (jas_image_cmptsgnd(jp2_image, components[i]) != false))
         {
             jas_image_destroy(jp2_image);
-            kDebug(50003) << "Error parsing JPEG2000 image : Irregular Channel Geometry Not Supported" << endl;
+            kDebug() << "Error parsing JPEG2000 image : Irregular Channel Geometry Not Supported";
             return false;
         }
 
@@ -233,7 +250,7 @@ bool JP2KLoader::load(const QString& filePath, DImgLoaderObserver *observer)
     m_hasAlpha              = number_components > 3;
     maximum_component_depth = 0;
 
-    for (i = 0; i < (long)number_components; i++)
+    for (i = 0; i < (long)number_components; ++i)
     {
         maximum_component_depth = qMax((long)jas_image_cmptprec(jp2_image,components[i]),
                                   (long)maximum_component_depth);
@@ -241,7 +258,7 @@ bool JP2KLoader::load(const QString& filePath, DImgLoaderObserver *observer)
         if (!pixels[i])
         {
             jas_image_destroy(jp2_image);
-            kDebug(50003) << "Error decoding JPEG2000 image data : Memory Allocation Failed" << endl;
+            kDebug() << "Error decoding JPEG2000 image data : Memory Allocation Failed";
             return false;
         }
     }
@@ -249,7 +266,7 @@ bool JP2KLoader::load(const QString& filePath, DImgLoaderObserver *observer)
     if (maximum_component_depth > 8)
         m_sixteenBit = true;
 
-    for (i = 0 ; i < (long)number_components ; i++)
+    for (i = 0 ; i < (long)number_components ; ++i)
     {
         scale[i] = 1;
         int prec = jas_image_cmptprec(jp2_image, components[i]);
@@ -265,15 +282,15 @@ bool JP2KLoader::load(const QString& filePath, DImgLoaderObserver *observer)
     if (m_loadFlags & LoadImageData)
     {
         if (m_sixteenBit)          // 16 bits image.
-            data = new uchar[imageWidth()*imageHeight()*8];
+            data = new_failureTolerant(imageWidth()*imageHeight()*8);
         else
-            data = new uchar[imageWidth()*imageHeight()*4];
+            data = new_failureTolerant(imageWidth()*imageHeight()*4);
 
         if (!data)
         {
-            kDebug(50003) << "Error decoding JPEG2000 image data : Memory Allocation Failed" << endl;
+            kDebug() << "Error decoding JPEG2000 image data : Memory Allocation Failed";
             jas_image_destroy(jp2_image);
-            for (i = 0 ; i < (long)number_components ; i++)
+            for (i = 0 ; i < (long)number_components ; ++i)
                 jas_matrix_destroy(pixels[i]);
 
             jas_cleanup();
@@ -284,9 +301,9 @@ bool JP2KLoader::load(const QString& filePath, DImgLoaderObserver *observer)
         uchar *dst            = data;
         unsigned short *dst16 = (unsigned short *)data;
 
-        for (y = 0 ; y < (long)imageHeight() ; y++)
+        for (y = 0 ; y < (long)imageHeight() ; ++y)
         {
-            for (i = 0 ; i < (long)number_components; i++)
+            for (i = 0 ; i < (long)number_components; ++i)
             {
                 int ret = jas_image_readcmpt(jp2_image, (short)components[i], 0,
                                              ((unsigned int) y)            / y_step[i],
@@ -294,10 +311,10 @@ bool JP2KLoader::load(const QString& filePath, DImgLoaderObserver *observer)
                                              1, pixels[i]);
                 if (ret != 0)
                 {
-                    kDebug(50003) << "Error decoding JPEG2000 image data" << endl;
+                    kDebug() << "Error decoding JPEG2000 image data";
                     delete [] data;
                     jas_image_destroy(jp2_image);
-                    for (i = 0 ; i < (long)number_components ; i++)
+                    for (i = 0 ; i < (long)number_components ; ++i)
                         jas_matrix_destroy(pixels[i]);
 
                     jas_cleanup();
@@ -309,7 +326,7 @@ bool JP2KLoader::load(const QString& filePath, DImgLoaderObserver *observer)
             {
                 case 1: // Grayscale.
                 {
-                    for (x = 0 ; x < (long)imageWidth() ; x++)
+                    for (x = 0 ; x < (long)imageWidth() ; ++x)
                     {
                         dst[0] = (uchar)(scale[0]*jas_matrix_getv(pixels[0], x/x_step[0]));
                         dst[1] = dst[0];
@@ -324,7 +341,7 @@ bool JP2KLoader::load(const QString& filePath, DImgLoaderObserver *observer)
                 {
                     if (!m_sixteenBit)   // 8 bits image.
                     {
-                        for (x = 0 ; x < (long)imageWidth() ; x++)
+                        for (x = 0 ; x < (long)imageWidth() ; ++x)
                         {
                             // Blue
                             dst[0] = (uchar)(scale[2]*jas_matrix_getv(pixels[2], x/x_step[2]));
@@ -340,7 +357,7 @@ bool JP2KLoader::load(const QString& filePath, DImgLoaderObserver *observer)
                     }
                     else                // 16 bits image.
                     {
-                        for (x = 0 ; x < (long)imageWidth() ; x++)
+                        for (x = 0 ; x < (long)imageWidth() ; ++x)
                         {
                             // Blue
                             dst16[0] = (unsigned short)(scale[2]*jas_matrix_getv(pixels[2], x/x_step[2]));
@@ -361,7 +378,7 @@ bool JP2KLoader::load(const QString& filePath, DImgLoaderObserver *observer)
                 {
                     if (!m_sixteenBit)   // 8 bits image.
                     {
-                        for (x = 0 ; x < (long)imageWidth() ; x++)
+                        for (x = 0 ; x < (long)imageWidth() ; ++x)
                         {
                             // Blue
                             dst[0] = (uchar)(scale[2] * jas_matrix_getv(pixels[2], x/x_step[2]));
@@ -377,7 +394,7 @@ bool JP2KLoader::load(const QString& filePath, DImgLoaderObserver *observer)
                     }
                     else                // 16 bits image.
                     {
-                        for (x = 0 ; x < (long)imageWidth() ; x++)
+                        for (x = 0 ; x < (long)imageWidth() ; ++x)
                         {
                             // Blue
                             dst16[0] = (unsigned short)(scale[2]*jas_matrix_getv(pixels[2], x/x_step[2]));
@@ -399,12 +416,12 @@ bool JP2KLoader::load(const QString& filePath, DImgLoaderObserver *observer)
             // use 0-10% and 90-100% for pseudo-progress
             if (observer && y >= (long)checkPoint)
             {
-                checkPoint += granularity(observer, y, 0.8);
+                checkPoint += granularity(observer, y, 0.8F);
                 if (!observer->continueQuery(m_image))
                 {
                     delete [] data;
                     jas_image_destroy(jp2_image);
-                    for (i = 0 ; i < (long)number_components ; i++)
+                    for (i = 0 ; i < (long)number_components ; ++i)
                     jas_matrix_destroy(pixels[i]);
 
                     jas_cleanup();
@@ -439,12 +456,11 @@ bool JP2KLoader::load(const QString& filePath, DImgLoaderObserver *observer)
                 {
                     if (jas_stream_flush(icc_stream) == 0)
                     {
-                        QMap<int, QByteArray>& metaData = imageMetaData();
                         jas_stream_memobj_t *blob = (jas_stream_memobj_t *) icc_stream->obj_;
                         QByteArray profile_rawdata;
                         profile_rawdata.resize(blob->len_);
                         memcpy(profile_rawdata.data(), blob->buf_, blob->len_);
-                        metaData.insert(DImg::ICC, profile_rawdata);
+                        imageSetIccProfile(profile_rawdata);
                         jas_stream_close(icc_stream);
                     }
                 }
@@ -461,7 +477,7 @@ bool JP2KLoader::load(const QString& filePath, DImgLoaderObserver *observer)
     imageSetAttribute("originalBitDepth", maximum_component_depth);
 
     jas_image_destroy(jp2_image);
-    for (i = 0 ; i < (long)number_components ; i++)
+    for (i = 0 ; i < (long)number_components ; ++i)
         jas_matrix_destroy(pixels[i]);
 
     jas_cleanup();
@@ -491,20 +507,20 @@ bool JP2KLoader::save(const QString& filePath, DImgLoaderObserver *observer)
     int init = jas_init();
     if (init != 0)
     {
-        kDebug(50003) << "Unable to init JPEG2000 decoder" << endl;
+        kDebug() << "Unable to init JPEG2000 decoder";
         return false;
     }
 
     jp2_stream = jas_stream_fopen(QFile::encodeName(filePath), "wb");
     if (jp2_stream == 0)
     {
-        kDebug(50003) << "Unable to open JPEG2000 stream" << endl;
+        kDebug() << "Unable to open JPEG2000 stream";
         return false;
     }
 
     number_components = imageHasAlpha() ? 4 : 3;
 
-    for (i = 0 ; i < (long)number_components ; i++)
+    for (i = 0 ; i < (long)number_components ; ++i)
     {
         component_info[i].tlx    = 0;
         component_info[i].tly    = 0;
@@ -520,12 +536,12 @@ bool JP2KLoader::save(const QString& filePath, DImgLoaderObserver *observer)
     if (jp2_image == 0)
     {
         jas_stream_close(jp2_stream);
-        kDebug(50003) << "Unable to create JPEG2000 image" << endl;
+        kDebug() << "Unable to create JPEG2000 image";
         return false;
     }
 
     if (observer)
-        observer->progressInfo(m_image, 0.1);
+        observer->progressInfo(m_image, 0.1F);
 
     // -------------------------------------------------------------------
     // Check color space.
@@ -550,7 +566,7 @@ bool JP2KLoader::save(const QString& filePath, DImgLoaderObserver *observer)
     jas_cmprof_t  *cm_profile  = 0;
     jas_iccprof_t *icc_profile = 0;
 
-    QByteArray profile_rawdata = m_image->getICCProfil();
+    QByteArray profile_rawdata = m_image->getIccProfile().data();
 
     icc_profile = jas_iccprof_createfrombuf((uchar*)profile_rawdata.data(), profile_rawdata.size());
     if (icc_profile != 0)
@@ -565,16 +581,16 @@ bool JP2KLoader::save(const QString& filePath, DImgLoaderObserver *observer)
     // -------------------------------------------------------------------
     // Convert to JPEG 2000 pixels.
 
-    for (i = 0 ; i < (long)number_components ; i++)
+    for (i = 0 ; i < (long)number_components ; ++i)
     {
         pixels[i] = jas_matrix_create(1, (unsigned int)imageWidth());
         if (pixels[i] == 0)
         {
-            for (x = 0 ; x < i ; x++)
+            for (x = 0 ; x < i ; ++x)
             jas_matrix_destroy(pixels[x]);
 
             jas_image_destroy(jp2_image);
-            kDebug(50003) << "Error encoding JPEG2000 image data : Memory Allocation Failed" << endl;
+            kDebug() << "Error encoding JPEG2000 image data : Memory Allocation Failed";
             return false;
         }
     }
@@ -584,15 +600,15 @@ bool JP2KLoader::save(const QString& filePath, DImgLoaderObserver *observer)
     unsigned short r, g, b, a=0;
     uint           checkpoint = 0;
 
-    for (y = 0 ; y < (long)imageHeight() ; y++)
+    for (y = 0 ; y < (long)imageHeight() ; ++y)
     {
         if (observer && y == (long)checkpoint)
         {
-            checkpoint += granularity(observer, imageHeight(), 0.8);
+            checkpoint += granularity(observer, imageHeight(), 0.8F);
             if (!observer->continueQuery(m_image))
             {
                 jas_image_destroy(jp2_image);
-                for (i = 0 ; i < (long)number_components ; i++)
+                for (i = 0 ; i < (long)number_components ; ++i)
                     jas_matrix_destroy(pixels[i]);
 
                 jas_cleanup();
@@ -602,7 +618,7 @@ bool JP2KLoader::save(const QString& filePath, DImgLoaderObserver *observer)
             observer->progressInfo(m_image, 0.1 + (0.8 * ( ((float)y)/((float)imageHeight()) )));
         }
 
-        for (x = 0 ; x < (long)imageWidth() ; x++)
+        for (x = 0 ; x < (long)imageWidth() ; ++x)
         {
             pixel = &data[((y * imageWidth()) + x) * imageBytesDepth()];
 
@@ -633,16 +649,16 @@ bool JP2KLoader::save(const QString& filePath, DImgLoaderObserver *observer)
                 jas_matrix_setv(pixels[3], x, a);
         }
 
-        for (i = 0 ; i < (long)number_components ; i++)
+        for (i = 0 ; i < (long)number_components ; ++i)
         {
             int ret = jas_image_writecmpt(jp2_image, (short) i, 0, (unsigned int)y,
                                           (unsigned int)imageWidth(), 1, pixels[i]);
             if (ret != 0)
             {
-                kDebug(50003) << "Error encoding JPEG2000 image data" << endl;
+                kDebug() << "Error encoding JPEG2000 image data";
 
                 jas_image_destroy(jp2_image);
-                for (i = 0 ; i < (long)number_components ; i++)
+                for (i = 0 ; i < (long)number_components ; ++i)
                     jas_matrix_destroy(pixels[i]);
 
                 jas_cleanup();
@@ -669,17 +685,17 @@ bool JP2KLoader::save(const QString& filePath, DImgLoaderObserver *observer)
     //                      the uncompressed size
     ts << "rate=" << ( quality / 100.0F );
 
-    kDebug(50003) << "JPEG2000 quality: " << quality << endl;
-    kDebug(50003) << "JPEG2000 " << rate << endl;
+    kDebug() << "JPEG2000 quality: " << quality;
+    kDebug() << "JPEG2000 " << rate;
 
     int ret = jp2_encode(jp2_image, jp2_stream, rate.toUtf8().data());
     if (ret != 0)
     {
-        kDebug(50003) << "Unable to encode JPEG2000 image" << endl;
+        kDebug() << "Unable to encode JPEG2000 image";
 
         jas_image_destroy(jp2_image);
         jas_stream_close(jp2_stream);
-        for (i = 0 ; i < (long)number_components ; i++)
+        for (i = 0 ; i < (long)number_components ; ++i)
             jas_matrix_destroy(pixels[i]);
 
         jas_cleanup();
@@ -696,7 +712,7 @@ bool JP2KLoader::save(const QString& filePath, DImgLoaderObserver *observer)
 
     jas_image_destroy(jp2_image);
     jas_stream_close(jp2_stream);
-    for (i = 0 ; i < (long)number_components ; i++)
+    for (i = 0 ; i < (long)number_components ; ++i)
         jas_matrix_destroy(pixels[i]);
 
     jas_cleanup();
