@@ -4,11 +4,11 @@
  * http://www.digikam.org
  *
  * Date        : 2005-11-01
- * Description : A digital camera RAW files loader for DImg 
+ * Description : A digital camera RAW files loader for DImg
  *               framework using an external dcraw instance.
  *
- * Copyright (C) 2005-2008 by Gilles Caulier <caulier dot gilles at gmail dot com> 
- * Copyright (C) 2005-2008 by Marcel Wiesweg <marcel.wiesweg@gmx.de>
+ * Copyright (C) 2005-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2010 by Marcel Wiesweg <marcel.wiesweg@gmx.de>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -50,11 +50,11 @@ public:
 
     explicit RAWLoader(DImg* image, DRawDecoding rawDecodingSettings=DRawDecoding());
 
-    bool load(const QString& filePath, DImgLoaderObserver *observer=0);
-    void postProcess(DImgLoaderObserver *observer);
+    bool load(const QString& filePath, DImgLoaderObserver* observer=0);
+    void postProcess(DImgLoaderObserver* observer);
 
     // NOTE: RAW files are always Read only.
-    bool save(const QString& /*filePath*/, DImgLoaderObserver * /*observer=0*/) { return false; };
+    bool save(const QString& /*filePath*/, DImgLoaderObserver* /*observer=0*/) { return false; };
 
     bool hasAlpha()   const { return false;                                  };
     bool isReadOnly() const { return true;                                   };
@@ -70,14 +70,9 @@ private:
     bool checkToCancelWaitingData();
     void setWaitingDataProgress(double value);
 
-#if KDCRAW_VERSION < 0x000400
-    bool checkToCancelReceivingData();
-    void setReceivingDataProgress(double value);
-#endif
-
 private:
 
-    DImgLoaderObserver *m_observer;
+    DImgLoaderObserver* m_observer;
     DRawDecoding        m_customRawSettings;
     IccProfile          m_customOutputProfile;
 };
