@@ -959,22 +959,26 @@ QStringList DMetadata::getIptcCoreSubjects() const
 
 QString DMetadata::getLensDescription() const
 {
-    QString lens;
+    QString     lens;
     QStringList lensExifTags;
 
     // In first, try to get Lens information from makernotes.
 
+    lensExifTags.append("Exif.CanonCs.LensType");      // Canon Cameras Makernote.
     lensExifTags.append("Exif.CanonCs.Lens");          // Canon Cameras Makernote.
     lensExifTags.append("Exif.Canon.0x0095");          // Alternative Canon Cameras Makernote.
     lensExifTags.append("Exif.NikonLd1.LensIDNumber"); // Nikon Cameras Makernote.
     lensExifTags.append("Exif.NikonLd2.LensIDNumber"); // Nikon Cameras Makernote.
     lensExifTags.append("Exif.NikonLd3.LensIDNumber"); // Nikon Cameras Makernote.
     lensExifTags.append("Exif.Minolta.LensID");        // Minolta Cameras Makernote.
+    lensExifTags.append("Exif.Sony1.LensID");          // Sony Cameras Makernote.
     lensExifTags.append("Exif.Sony2.LensID");          // Sony Cameras Makernote.
+    lensExifTags.append("Exif.SonyMinolta.LensID");    // Sony Cameras Makernote.
     lensExifTags.append("Exif.Pentax.LensType");       // Pentax Cameras Makernote.
     lensExifTags.append("Exif.Panasonic.0x0051");      // Panasonic Cameras Makernote.
     lensExifTags.append("Exif.Panasonic.0x0310");      // Panasonic Cameras Makernote.
     lensExifTags.append("Exif.Sigma.LensRange");       // Sigma Cameras Makernote.
+    lensExifTags.append("Exif.Samsung2.LensType");     // Samsung Cameras Makernote.
     lensExifTags.append("Exif.Photo.0xFDEA");          // Non-standard Exif tag set by Camera Raw.
 
     // TODO : add Fuji and Olympus, camera Makernotes.
@@ -990,7 +994,8 @@ QString DMetadata::getLensDescription() const
     for (QStringList::Iterator it = lensExifTags.begin(); it != lensExifTags.end(); ++it)
     {
         lens = getExifTagString((*it).toAscii());
-        if (!lens.isEmpty())
+        if ( !lens.isEmpty() &&
+             !(lens.startsWith('(') && lens.endsWith(')')) )   // To prevent undecoded tag values from Exiv2 as "(65535)".
             return lens;
     }
 
@@ -1886,5 +1891,13 @@ void DMetadata::setData(const KExiv2Data& data)
 // End: Compatibility for < KDE 4.4
 //------------------------------------------------------------------------------------------------
 
+// NOTE: this method can be moved to libkexiv2 later...
+bool DMetadata::removeExifColorSpace() const
+{
+    bool ret = true;
+    ret      &= removeExifTag("Exif.Photo.ColorSpace", true);
+    ret      &= removeXmpTag("Xmp.exif.ColorSpace", true);
+    return ret;
+}
 
 }  // namespace Digikam
