@@ -7,10 +7,10 @@
  * Description : Captions, Tags, and Rating properties editor
  *
  * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
- * Copyright (C) 2003-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2006-2009 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2009 by Andi Clemens <andi dot clemens at gmx dot net>
- * Copyright (C) 2009 by Johannes Wienke <languitar at semipol dot de>
+ * Copyright (C) 2003-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * Copyright (C) 2009-2010 by Andi Clemens <andi dot clemens at gmx dot net>
+ * Copyright (C) 2009-2010 by Johannes Wienke <languitar at semipol dot de>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -50,8 +50,8 @@
 
 #include "captionedit.h"
 #include "kdatetimeedit.h"
+#include "addtagslineedit.h"
 #include "albumsettings.h"
-#include "albumlister.h"
 #include "albumthumbnailloader.h"
 #include "collectionscanner.h"
 #include "databasetransaction.h"
@@ -68,7 +68,7 @@
 namespace Digikam
 {
 
-class ImageDescEditTabPriv
+class ImageDescEditTab::ImageDescEditTabPriv
 {
 
 public:
@@ -103,51 +103,50 @@ public:
         tagCheckView               = 0;
     }
 
-    bool                           modified;
-    bool                           ignoreImageAttributesWatch;
-    bool                           ignoreTagChanges;
+    bool                 modified;
+    bool                 ignoreImageAttributesWatch;
+    bool                 ignoreTagChanges;
 
-    QToolButton                   *recentTagsBtn;
-    QToolButton                   *assignedTagsBtn;
-    QToolButton                   *revertBtn;
+    QToolButton*         recentTagsBtn;
+    QToolButton*         assignedTagsBtn;
+    QToolButton*         revertBtn;
 
-    KMenu                         *moreMenu;
+    KMenu*               moreMenu;
 
-    QSignalMapper                 *recentTagsMapper;
+    QSignalMapper*       recentTagsMapper;
 
-    QPushButton                   *applyBtn;
-    QPushButton                   *moreButton;
+    QPushButton*         applyBtn;
+    QPushButton*         moreButton;
 
-    QWidget                       *lastSelectedWidget;
+    QWidget*             lastSelectedWidget;
 
-    CaptionEdit                   *captionsEdit;
+    CaptionEdit*         captionsEdit;
 
-    KDateTimeEdit                 *dateTimeEdit;
+    KDateTimeEdit*       dateTimeEdit;
 
-    KTabWidget                    *tabWidget;
+    KTabWidget*          tabWidget;
 
-    SearchTextBar                 *tagsSearchBar;
-    SearchTextBar                 *newTagEdit;
+    SearchTextBar*       tagsSearchBar;
+    AddTagsLineEdit*     newTagEdit;
 
-    ImageInfoList                  currInfos;
+    ImageInfoList        currInfos;
 
-    TagCheckView                  *tagCheckView;
+    TagCheckView*        tagCheckView;
 
-    TemplateSelector              *templateSelector;
-    TemplateViewer                *templateViewer;
+    TemplateSelector*    templateSelector;
+    TemplateViewer*      templateViewer;
 
-    RatingWidget                  *ratingWidget;
+    RatingWidget*        ratingWidget;
 
-    MetadataHubOnTheRoad           hub;
+    MetadataHubOnTheRoad hub;
 
-    TagModel                      *tagModel;
-
-    QTimer                        *metadataChangeTimer;
-    QList<int>                     metadataChangeIds;
+    TagModel*            tagModel;
 
+    QTimer*              metadataChangeTimer;
+    QList<int>           metadataChangeIds;
 };
 
-ImageDescEditTab::ImageDescEditTab(QWidget *parent)
+ImageDescEditTab::ImageDescEditTab(QWidget* parent)
                 : KVBox(parent), d(new ImageDescEditTabPriv)
 {
     setMargin(0);
@@ -160,42 +159,46 @@ ImageDescEditTab::ImageDescEditTab(QWidget *parent)
 
     // Captions/Date/Rating view -----------------------------------
 
-    QScrollArea *sv = new QScrollArea(d->tabWidget);
+    QScrollArea* sv = new QScrollArea(d->tabWidget);
     sv->setFrameStyle(QFrame::NoFrame);
     sv->setWidgetResizable(true);
 
-    QWidget *captionTagsArea = new QWidget(sv->viewport());
-    QGridLayout *grid1       = new QGridLayout(captionTagsArea);
+    QWidget* captionTagsArea = new QWidget(sv->viewport());
+    QGridLayout* grid1       = new QGridLayout(captionTagsArea);
     sv->setWidget(captionTagsArea);
     sv->viewport()->setAutoFillBackground(false);
     captionTagsArea->setAutoFillBackground(false);
 
     d->captionsEdit = new CaptionEdit(captionTagsArea);
 
-    KHBox *dateBox  = new KHBox(captionTagsArea);
+    KHBox* dateBox  = new KHBox(captionTagsArea);
     new QLabel(i18n("Date:"), dateBox);
     d->dateTimeEdit = new KDateTimeEdit(dateBox, "datepicker");
 
-    KHBox *ratingBox = new KHBox(captionTagsArea);
+    KHBox* ratingBox = new KHBox(captionTagsArea);
     new QLabel(i18n("Rating:"), ratingBox);
     d->ratingWidget  = new RatingWidget(ratingBox);
     ratingBox->layout()->setAlignment(d->ratingWidget, Qt::AlignVCenter|Qt::AlignRight);
 
     // Tags view ---------------------------------------------------
 
-    d->newTagEdit = new SearchTextBar(captionTagsArea, "ImageDescEditTabNewTagEdit", i18n("Enter new tag here..."));
-    d->newTagEdit->setCaseSensitive(false);
-    d->newTagEdit->setWhatsThis(i18n("Enter the text used to create new tags here. "
-                                     "'/' can be used to create a hierarchy of tags. "
-                                     "',' can be used to create more than one hierarchy at the same time."));
-
     d->tagModel = new TagModel(AbstractAlbumModel::IncludeRootAlbum, this);
     d->tagModel->setCheckable(true);
     d->tagModel->setRootCheckable(false);
     d->tagCheckView = new TagCheckView(captionTagsArea, d->tagModel);
     d->tagCheckView->setCheckNewTags(true);
 
-    KHBox *tagsSearch  = new KHBox(captionTagsArea);
+    d->newTagEdit = new AddTagsLineEdit(captionTagsArea);
+    d->newTagEdit->setTagModel(d->tagModel);
+    d->newTagEdit->setTagTreeView(d->tagCheckView);
+    //, "ImageDescEditTabNewTagEdit",
+    //d->newTagEdit->setCaseSensitive(false);
+    d->newTagEdit->setClickMessage(i18n("Enter new tag here..."));
+    //d->newTagEdit->setWhatsThis(i18n("Enter the text used to create new tags here. "
+    //                                 "'/' can be used to create a hierarchy of tags. "
+    //                                 "',' can be used to create more than one hierarchy at the same time."));
+
+    KHBox* tagsSearch  = new KHBox(captionTagsArea);
     tagsSearch->setSpacing(KDialog::spacingHint());
 
     d->tagsSearchBar   = new SearchTextBar(tagsSearch, "ImageDescEditTabTagsSearchBar");
@@ -209,7 +212,7 @@ ImageDescEditTab::ImageDescEditTab(QWidget *parent)
     d->assignedTagsBtn->setCheckable(true);
 
     d->recentTagsBtn      = new QToolButton(tagsSearch);
-    KMenu *recentTagsMenu = new KMenu(d->recentTagsBtn);
+    KMenu* recentTagsMenu = new KMenu(d->recentTagsBtn);
     d->recentTagsBtn->setToolTip( i18n("Recent Tags"));
     d->recentTagsBtn->setIcon(KIconLoader::global()->loadIcon("tag-recents",
                               KIconLoader::NoGroup, KIconLoader::SizeSmall));
@@ -220,7 +223,7 @@ ImageDescEditTab::ImageDescEditTab(QWidget *parent)
 
     // Buttons -----------------------------------------
 
-    KHBox *buttonsBox = new KHBox(this);
+    KHBox* buttonsBox = new KHBox(this);
     buttonsBox->setSpacing(KDialog::spacingHint());
 
     d->revertBtn = new QToolButton(buttonsBox);
@@ -254,12 +257,12 @@ ImageDescEditTab::ImageDescEditTab(QWidget *parent)
 
     // Information Managament View --------------------------------------
 
-    QScrollArea *sv2 = new QScrollArea(d->tabWidget);
+    QScrollArea* sv2 = new QScrollArea(d->tabWidget);
     sv2->setFrameStyle(QFrame::NoFrame);
     sv2->setWidgetResizable(true);
 
-    QWidget *infoArea = new QWidget(sv->viewport());
-    QGridLayout *grid2 = new QGridLayout(infoArea);
+    QWidget* infoArea = new QWidget(sv->viewport());
+    QGridLayout* grid2 = new QGridLayout(infoArea);
     sv2->setWidget(infoArea);
     sv2->viewport()->setAutoFillBackground(false);
     infoArea->setAutoFillBackground(false);
@@ -283,7 +286,7 @@ ImageDescEditTab::ImageDescEditTab(QWidget *parent)
     connect(d->captionsEdit, SIGNAL(signalModified()),
             this, SLOT(slotCommentChanged()));
 
-    connect(d->dateTimeEdit, SIGNAL(dateTimeChanged(const QDateTime& )),
+    connect(d->dateTimeEdit, SIGNAL(dateTimeChanged(const QDateTime&)),
             this, SLOT(slotDateTimeChanged(const QDateTime&)));
 
     connect(d->ratingWidget, SIGNAL(signalRatingChanged(int)),
@@ -298,8 +301,8 @@ ImageDescEditTab::ImageDescEditTab(QWidget *parent)
     connect(d->assignedTagsBtn, SIGNAL(toggled(bool)),
             this, SLOT(slotAssignedTagsToggled(bool)));
 
-    connect(d->newTagEdit, SIGNAL(returnPressed(const QString&)),
-            this, SLOT(slotCreateNewTag()));
+    connect(d->newTagEdit, SIGNAL(taggingActionActivated(const TaggingAction&)),
+            this, SLOT(slotTaggingActionActivated(const TaggingAction&)));
 
     connect(d->applyBtn, SIGNAL(clicked()),
             this, SLOT(slotApplyAllChanges()));
@@ -327,7 +330,7 @@ ImageDescEditTab::ImageDescEditTab(QWidget *parent)
 
     // Connect to attribute watch ------------------------------
 
-    ImageAttributesWatch *watch = ImageAttributesWatch::instance();
+    ImageAttributesWatch* watch = ImageAttributesWatch::instance();
 
     connect(watch, SIGNAL(signalImageTagsChanged(qlonglong)),
             this, SLOT(slotImageTagsChanged(qlonglong)));
@@ -369,7 +372,7 @@ ImageDescEditTab::~ImageDescEditTab()
     //slotChangingItems();
 
     KSharedConfig::Ptr config = KGlobal::config();
-    KConfigGroup group       = config->group("Image Properties SideBar");
+    KConfigGroup group        = config->group("Image Properties SideBar");
     group.writeEntry("ImageDescEditTab Tab", d->tabWidget->currentIndex());
     group.sync();
 
@@ -394,7 +397,7 @@ void ImageDescEditTab::slotChangingItems()
 
     if (!AlbumSettings::instance()->getApplySidebarChangesDirectly())
     {
-        KDialog *dialog = new KDialog(this);
+        KDialog* dialog = new KDialog(this);
 
         dialog->setCaption(i18n("Apply changes?"));
         dialog->setButtons(KDialog::Yes | KDialog::No);
@@ -558,10 +561,9 @@ void ImageDescEditTab::slotReadFromFileMetadataToDatabase()
                                i18n("Reading metadata from files. Please wait..."));
 
     d->ignoreImageAttributesWatch = true;
-    int i = 0;
+    int i                         = 0;
 
     DatabaseTransaction transaction;
-    AlbumLister::instance()->blockSignals(true);
     ScanController::instance()->suspendCollectionScan();
 
     CollectionScanner scanner;
@@ -583,7 +585,6 @@ void ImageDescEditTab::slotReadFromFileMetadataToDatabase()
     }
 
     ScanController::instance()->resumeCollectionScan();
-    AlbumLister::instance()->blockSignals(false);
     d->ignoreImageAttributesWatch = false;
 
     emit signalProgressBarMode(StatusProgressBar::TextMode, QString());
@@ -596,9 +597,8 @@ void ImageDescEditTab::slotWriteToFileMetadataFromDatabase()
 {
     emit signalProgressBarMode(StatusProgressBar::ProgressBarMode,
                                i18n("Writing metadata to files. Please wait..."));
-    MetadataWriteSettings writeSettings = MetadataHub::defaultWriteSettings();
 
-    int i=0;
+    int i = 0;
     foreach(const ImageInfo& info, d->currInfos)
     {
         MetadataHub fileHub;
@@ -614,11 +614,11 @@ void ImageDescEditTab::slotWriteToFileMetadataFromDatabase()
     emit signalProgressBarMode(StatusProgressBar::TextMode, QString());
 }
 
-bool ImageDescEditTab::eventFilter(QObject *o, QEvent *e)
+bool ImageDescEditTab::eventFilter(QObject* o, QEvent* e)
 {
     if ( e->type() == QEvent::KeyPress )
     {
-        QKeyEvent *k = static_cast<QKeyEvent *>(e);
+        QKeyEvent* k = static_cast<QKeyEvent*>(e);
 
         if (k->key() == Qt::Key_Enter || k->key() == Qt::Key_Return)
         {
@@ -646,9 +646,9 @@ void ImageDescEditTab::populateTags()
     //d->tagCheckView->loadViewState(group);
 }
 
-void ImageDescEditTab::slotTagStateChanged(Album *album, Qt::CheckState checkState)
+void ImageDescEditTab::slotTagStateChanged(Album* album, Qt::CheckState checkState)
 {
-    TAlbum *tag = dynamic_cast<TAlbum*> (album);
+    TAlbum* tag = dynamic_cast<TAlbum*> (album);
     if (!tag || d->ignoreTagChanges)
     {
         return;
@@ -712,7 +712,7 @@ void ImageDescEditTab::slotCreateNewTag()
     {
         return;
     }
-    TAlbum *created = d->tagCheckView->tagModificationHelper()->
+    TAlbum* created = d->tagCheckView->tagModificationHelper()->
                             slotTagNew(d->tagCheckView->currentAlbum(), d->newTagEdit->text());
     if (created)
     {
@@ -721,14 +721,36 @@ void ImageDescEditTab::slotCreateNewTag()
     }
 }
 
+void ImageDescEditTab::slotTaggingActionActivated(const TaggingAction& action)
+{
+    TAlbum* assigned = 0;
+    if (action.shallAssignTag())
+    {
+        assigned = AlbumManager::instance()->findTAlbum(action.tagId());
+        if (assigned)
+            d->tagModel->setChecked(assigned, true);
+    }
+    else if (action.shallCreateNewTag())
+    {
+        TAlbum* parent = AlbumManager::instance()->findTAlbum(action.parentTagId());
+        // tag is assigned automatically
+        assigned = d->tagCheckView->tagModificationHelper()->slotTagNew(parent, action.newTagName());
+    }
+
+    if (assigned)
+    {
+        d->newTagEdit->clear();
+        d->tagCheckView->scrollTo(d->tagCheckView->albumFilterModel()->indexForAlbum(assigned));
+    }
+}
+
 void ImageDescEditTab::assignRating(int rating)
 {
     d->ratingWidget->setRating(rating);
 }
 
-void ImageDescEditTab::setTagState(TAlbum *tag, MetadataHub::TagStatus status)
+void ImageDescEditTab::setTagState(TAlbum* tag, MetadataHub::TagStatus status)
 {
-
     if (!tag)
     {
         return;
@@ -736,24 +758,22 @@ void ImageDescEditTab::setTagState(TAlbum *tag, MetadataHub::TagStatus status)
 
     switch(status.status)
     {
-    case MetadataHub::MetadataDisjoint:
-        d->tagModel->setCheckState(tag, Qt::PartiallyChecked);
-        break;
-    case MetadataHub::MetadataAvailable:
-    case MetadataHub::MetadataInvalid:
-        d->tagModel->setChecked(tag, status.hasTag);
-        break;
-    default:
-        kWarning() << "Untreated tag status enum value " << status.status;
-        d->tagModel->setCheckState(tag, Qt::PartiallyChecked);
+        case MetadataHub::MetadataDisjoint:
+            d->tagModel->setCheckState(tag, Qt::PartiallyChecked);
+            break;
+        case MetadataHub::MetadataAvailable:
+        case MetadataHub::MetadataInvalid:
+            d->tagModel->setChecked(tag, status.hasTag);
+            break;
+        default:
+            kWarning() << "Untreated tag status enum value " << status.status;
+            d->tagModel->setCheckState(tag, Qt::PartiallyChecked);
     }
-
 }
 
-void ImageDescEditTab::initializeTags(QModelIndex &parent)
+void ImageDescEditTab::initializeTags(QModelIndex& parent)
 {
-
-    TAlbum *tag = d->tagModel->albumForIndex(parent);
+    TAlbum* tag = d->tagModel->albumForIndex(parent);
     if (!tag)
     {
         return;
@@ -766,17 +786,15 @@ void ImageDescEditTab::initializeTags(QModelIndex &parent)
         QModelIndex index = d->tagModel->index(row, 0, parent);
         initializeTags(index);
     }
-
 }
 
 void ImageDescEditTab::updateTagsView()
 {
-
     // avoid that the automatic tag toggling handles these calls and
     // modification is indicated to this widget
     TagCheckView::ToggleAutoTags toggle = d->tagCheckView->getToggleAutoTags();
     d->tagCheckView->setToggleAutoTags(TagCheckView::NoToggleAuto);
-    d->ignoreTagChanges = true;
+    d->ignoreTagChanges                 = true;
 
     // first reset the tags completely
     d->tagModel->resetAllCheckedAlbums();
@@ -795,8 +813,6 @@ void ImageDescEditTab::updateTagsView()
     // See comments in these methods.
     if (d->assignedTagsBtn->isChecked())
         slotAssignedTagsToggled(d->assignedTagsBtn->isChecked());
-
-
 }
 
 void ImageDescEditTab::updateComments()
@@ -834,7 +850,7 @@ void ImageDescEditTab::updateTemplate()
     d->templateSelector->blockSignals(false);
 }
 
-void ImageDescEditTab::setMetadataWidgetStatus(int status, QWidget *widget)
+void ImageDescEditTab::setMetadataWidgetStatus(int status, QWidget* widget)
 {
     if (status == MetadataHub::MetadataDisjoint)
     {
@@ -888,7 +904,7 @@ void ImageDescEditTab::slotImagesChanged(int albumId)
     if (d->ignoreImageAttributesWatch || d->modified)
         return;
 
-    Album *a = AlbumManager::instance()->findAlbum(albumId);
+    Album* a = AlbumManager::instance()->findAlbum(albumId);
     if (d->currInfos.isEmpty() || !a || a->isRoot() || a->type() != Album::TAG)
         return;
 
@@ -963,7 +979,7 @@ void ImageDescEditTab::slotReloadForMetadataChange()
 
 void ImageDescEditTab::updateRecentTags()
 {
-    KMenu *menu = dynamic_cast<KMenu *>(d->recentTagsBtn->menu());
+    KMenu* menu = dynamic_cast<KMenu *>(d->recentTagsBtn->menu());
     if (!menu) return;
 
     menu->clear();
@@ -972,7 +988,7 @@ void ImageDescEditTab::updateRecentTags()
 
     if (recentTags.isEmpty())
     {
-        QAction *noTagsAction = menu->addAction(i18n("No Recently Assigned Tags"));
+        QAction* noTagsAction = menu->addAction(i18n("No Recently Assigned Tags"));
         noTagsAction->setEnabled(false);
     }
     else
@@ -983,8 +999,8 @@ void ImageDescEditTab::updateRecentTags()
             TAlbum* album = static_cast<TAlbum*>(*it);
             if (album)
             {
-                AlbumThumbnailLoader *loader = AlbumThumbnailLoader::instance();
-                QPixmap icon;
+                AlbumThumbnailLoader* loader = AlbumThumbnailLoader::instance();
+                QPixmap               icon;
                 if (!loader->getTagThumbnail(album, icon))
                 {
                     if (icon.isNull())
@@ -1024,13 +1040,11 @@ void ImageDescEditTab::slotRecentTagsMenuActivated(int id)
 
 void ImageDescEditTab::slotTagsSearchChanged(const SearchTextSettings& settings)
 {
-
     Q_UNUSED(settings);
 
     // if we filter, we should reset the assignedTagsBtn again
     d->assignedTagsBtn->setChecked(false);
     slotAssignedTagsToggled(false);
-
 }
 
 void ImageDescEditTab::slotAssignedTagsToggled(bool t)
