@@ -213,11 +213,7 @@ void ImagePropertiesSideBarDB::slotChangedTab(QWidget* tab)
         {
             if (m_image)
             {
-                DMetadata data;
-                data.setComments(m_image->getComments());
-                data.setExif(m_image->getExif());
-                data.setIptc(m_image->getIptc());
-                data.setXmp(m_image->getXmp());
+                DMetadata data(m_image->getMetadata());
                 m_metadataTab->setCurrentData(data, m_currentURL.fileName());
             }
             else
@@ -254,11 +250,7 @@ void ImagePropertiesSideBarDB::slotChangedTab(QWidget* tab)
         {
             if (m_image)
             {
-                DMetadata data;
-                data.setComments(m_image->getComments());
-                data.setExif(m_image->getExif());
-                data.setIptc(m_image->getIptc());
-                data.setXmp(m_image->getXmp());
+                DMetadata data(m_image->getMetadata());
                 m_metadataTab->setCurrentData(data, m_currentURL.fileName());
             }
             else
