@@ -29,12 +29,12 @@
 
 #include "jpegutils.h"
 
-// C++ includes.
+// C++ includes
 
 #include <cstdio>
 #include <cstdlib>
 
-// C ANSI includes.
+// C ANSI includes
 
 extern "C"
 {
@@ -46,18 +46,18 @@ extern "C"
 #include <jpeglib.h>
 }
 
-// Qt includes.
+// KDE includes
+
+#include <kdebug.h>
+
+// Qt includes
 
 #include <QImageReader>
 #include <QByteArray>
 #include <QFile>
 #include <QFileInfo>
 
-// KDE includes.
-
-#include <kdebug.h>
-
-// Local includes.
+// Local includes
 
 #include "dmetadata.h"
 #include "transupp.h"
@@ -90,7 +90,7 @@ static void jpegutils_jpeg_error_exit(j_common_ptr cinfo)
     (*cinfo->err->format_message)(cinfo, buffer);
 
 #ifdef ENABLE_DEBUG_MESSAGES
-    kDebug(50003) << buffer << endl;
+    kDebug() << buffer;
 #endif
 
     longjmp(myerr->setjmp_buffer, 1);
@@ -103,7 +103,7 @@ static void jpegutils_jpeg_emit_message(j_common_ptr cinfo, int msg_level)
     (*cinfo->err->format_message)(cinfo, buffer);
 
 #ifdef ENABLE_DEBUG_MESSAGES
-    kDebug(50003) << buffer << " (" << msg_level << ")" << endl;
+    kDebug() << buffer << " (" << msg_level << ")";
 #endif
 }
 
@@ -113,7 +113,7 @@ static void jpegutils_jpeg_output_message(j_common_ptr cinfo)
     (*cinfo->err->format_message)(cinfo, buffer);
 
 #ifdef ENABLE_DEBUG_MESSAGES
-    kDebug(50003) << buffer << endl;
+    kDebug() << buffer;
 #endif
 }
 
@@ -125,8 +125,8 @@ bool loadJPEGScaled(QImage& image, const QString& path, int maximumSize)
     if(!inputFile)
         return false;
 
-    struct jpeg_decompress_struct cinfo;
-    struct jpegutils_jpeg_error_mgr       jerr;
+    struct jpeg_decompress_struct   cinfo;
+    struct jpegutils_jpeg_error_mgr jerr;
 
     // JPEG error handling - thanks to Marcus Meissner
     cinfo.err                 = jpeg_std_error(&jerr);
@@ -145,7 +145,8 @@ bool loadJPEGScaled(QImage& image, const QString& path, int maximumSize)
 #ifdef Q_CC_MSVC
     QFile inFile(path);
     QByteArray buffer;
-    if(inFile.open(QIODevice::ReadOnly)) {
+    if(inFile.open(QIODevice::ReadOnly))
+    {
         buffer = inFile.readAll();
         inFile.close();
     }
@@ -166,8 +167,9 @@ bool loadJPEGScaled(QImage& image, const QString& path, int maximumSize)
     }
     if(scale>8) scale=8;
 
-    cinfo.scale_num=1;
-    cinfo.scale_denom=scale;
+    //cinfo.scale_num = 1;
+    //cinfo.scale_denom = scale;
+    cinfo.scale_denom *= scale;
 
     switch (cinfo.jpeg_color_space)
     {
@@ -208,46 +210,57 @@ bool loadJPEGScaled(QImage& image, const QString& path, int maximumSize)
         case 1: // B&W image
             img = QImage( cinfo.output_width, cinfo.output_height, QImage::Format_Indexed8);
             img.setNumColors(256);
-            for (int i = 0 ; i < 256 ; i++)
+            for (int i = 0 ; i < 256 ; ++i)
                 img.setColor(i, qRgb(i, i, i));
             break;
     }
 
     uchar* data = img.bits();
     int bpl = img.bytesPerLine();
-    while (cinfo.output_scanline < cinfo.output_height) {
+    while (cinfo.output_scanline < cinfo.output_height)
+    {
         uchar *d = data + cinfo.output_scanline * bpl;
         jpeg_read_scanlines(&cinfo, &d, 1);
     }
     jpeg_finish_decompress(&cinfo);
 
-    if (cinfo.output_components == 3) {
+    if (cinfo.output_components == 3)
+    {
         // Expand 24->32 bpp.
-        for (uint j=0; j<cinfo.output_height; j++) {
+        for (uint j=0; j<cinfo.output_height; ++j)
+        {
             uchar *in = img.scanLine(j) + cinfo.output_width * 3;
             QRgb *out = (QRgb*)img.scanLine(j);
 
-            for (uint i = cinfo.output_width; i--; ) {
+            for (uint i = cinfo.output_width; --i; )
+            {
                 in -= 3;
                 out[i] = qRgb(in[0], in[1], in[2]);
             }
         }
-    } else if (cinfo.out_color_space == JCS_CMYK) {
-        for (uint j = 0; j < cinfo.output_height; ++j) {
+    }
+    else if (cinfo.out_color_space == JCS_CMYK)
+    {
+        for (uint j = 0; j < cinfo.output_height; ++j)
+        {
             uchar *in = img.scanLine(j) + cinfo.output_width * 4;
             QRgb *out = (QRgb*)img.scanLine(j);
 
-            for (uint i = cinfo.output_width; i--; ) {
+            for (uint i = cinfo.output_width; --i; )
+            {
                 in -= 4;
                 int k = in[3];
                 out[i] = qRgb(k * in[0] / 255, k * in[1] / 255, k * in[2] / 255);
             }
         }
     }
-    if (cinfo.density_unit == 1) {
+    if (cinfo.density_unit == 1)
+    {
         img.setDotsPerMeterX(int(100. * cinfo.X_density / 2.54));
         img.setDotsPerMeterY(int(100. * cinfo.Y_density / 2.54));
-    } else if (cinfo.density_unit == 2) {
+    }
+    else if (cinfo.density_unit == 2)
+    {
         img.setDotsPerMeterX(int(100. * cinfo.X_density));
         img.setDotsPerMeterY(int(100. * cinfo.Y_density));
     }
@@ -269,7 +282,7 @@ bool exifTransform(const QString& file, const QString& documentName,
     QFileInfo fi(file);
     if (!fi.exists())
     {
-        kDebug(50003) << "ExifRotate: file do not exist: " << file << endl;
+        kDebug() << "ExifRotate: file do not exist: " << file;
         return false;
     }
 
@@ -278,7 +291,7 @@ bool exifTransform(const QString& file, const QString& documentName,
         DMetadata metaData;
         if (!metaData.load(file))
         {
-            kDebug(50003) << "ExifRotate: no Exif data found: " << file << endl;
+            kDebug() << "ExifRotate: no Exif data found: " << file;
             return true;
         }
 
@@ -373,7 +386,7 @@ bool exifTransform(const QString& file, const QString& documentName,
 
         if (transformoption.transform == JXFORM_NONE)
         {
-            kDebug(50003) << "ExifRotate: no rotation to perform: " << file << endl;
+            kDebug() << "ExifRotate: no rotation to perform: " << file;
 
             if (trgFile.isEmpty())
             {
@@ -414,7 +427,7 @@ bool exifTransform(const QString& file, const QString& documentName,
             input_file = fopen(in, "rb");
             if (!input_file)
             {
-                kWarning(50003) << "ExifRotate: Error in opening input file: " << input_file << endl;
+                kWarning() << "ExifRotate: Error in opening input file: " << input_file;
                 return false;
             }
 
@@ -422,7 +435,7 @@ bool exifTransform(const QString& file, const QString& documentName,
             if (!output_file)
             {
                 fclose(input_file);
-                kWarning(50003) << "ExifRotate: Error in opening output file: " << output_file  << endl;
+                kWarning() << "ExifRotate: Error in opening output file: " << output_file;
                 return false;
             }
 
@@ -476,7 +489,7 @@ bool exifTransform(const QString& file, const QString& documentName,
             // -- Metadata operations ------------------------------------------------------
 
             // Reset the Exif orientation tag of the temp image to normal
-            kDebug(50003) << "ExifRotate: set Orientation tag to normal: " << file << endl;
+            kDebug() << "ExifRotate: set Orientation tag to normal: " << file;
 
             metaData.load(temp);
             metaData.setImageOrientation(DMetadata::ORIENTATION_NORMAL);
@@ -531,7 +544,7 @@ bool exifTransform(const QString& file, const QString& documentName,
     }
 
     // Not a jpeg image.
-    kDebug(50003) << "ExifRotate: not a JPEG file: " << file << endl;
+    kDebug() << "ExifRotate: not a JPEG file: " << file;
     return false;
 }
 
@@ -540,7 +553,7 @@ bool jpegConvert(const QString& src, const QString& dest, const QString& documen
     QFileInfo fi(src);
     if (!fi.exists())
     {
-        kDebug(50003) << "JpegConvert: file do not exist: " << src << endl;
+        kDebug() << "JpegConvert: file do not exist: " << src;
         return false;
     }
 
@@ -549,9 +562,7 @@ bool jpegConvert(const QString& src, const QString& dest, const QString& documen
         DImg image(src);
 
         // Get image Exif/IPTC data.
-        DMetadata meta;
-        meta.setExif(image.getExif());
-        meta.setIptc(image.getIptc());
+        DMetadata meta(image.getMetadata());
 
         // Update IPTC preview.
         QImage preview = image.smoothScale(1280, 1024, Qt::KeepAspectRatio).copyQImage();
@@ -575,8 +586,7 @@ bool jpegConvert(const QString& src, const QString& dest, const QString& documen
         meta.setExifTagString("Exif.Image.DocumentName", documentName);
 
         // Store new Exif/IPTC data into image.
-        image.setExif(meta.getExif());
-        image.setIptc(meta.getIptc());
+        image.setMetadata(meta.data());
 
         // And now save the image to a new file format.
 
@@ -586,6 +596,14 @@ bool jpegConvert(const QString& src, const QString& dest, const QString& documen
         if ( format.toUpper() == QString("TIFF") || format.toUpper() == QString("TIF") )
             image.setAttribute("compress", true);
 
+        if ( format.toUpper() == QString("JP2") || format.toUpper() == QString("JPX") ||
+             format.toUpper() == QString("JPC") || format.toUpper() == QString("PGX") ||
+             format.toUpper() == QString("J2K") )
+            image.setAttribute("quality", 100);      // LossLess
+
+        if ( format.toUpper() == QString("PGF") )
+            image.setAttribute("quality", 0);      // LossLess
+
         return (image.save(dest, format));
     }
 
@@ -596,7 +614,7 @@ bool isJpegImage(const QString& file)
 {
     // Check if the file is an JPEG image
     QString format = QString(QImageReader::imageFormat(file)).toUpper();
-    kDebug(50003) << "mimetype = " << format << endl;
+    kDebug() << "mimetype = " << format;
     if (format !="JPEG") return false;
 
     return true;
