@@ -6,7 +6,7 @@
  * Date        : 2007-27-08
  * Description : a tool bar action object to display animated logo
  *
- * Copyright (C) 2007-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -53,16 +53,16 @@
 namespace Digikam
 {
 
-class DLogoActionPriv
+class DLogoAction::DLogoActionPriv
 {
 public:
 
     DLogoActionPriv()
     {
-        alignOnright   = true;
-        progressTimer  = 0;
-        urlLabel       = 0;
-        progressCount  = 0;
+        alignOnright  = true;
+        progressTimer = 0;
+        urlLabel      = 0;
+        progressCount = 0;
     }
 
     bool       alignOnright;
