@@ -6,7 +6,7 @@
  * Date        : 2006-01-10
  * Description : a widget to display CIE tongue from an ICC profile.
  *
- * Copyright (C) 2006-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * Any source code are inspired from lprof project and
  * Copyright (C) 1998-2001 Marti Maria
@@ -152,7 +152,7 @@ namespace Digikam
         { 0.7347, 0.2653 }  // 780 nm
     };
 
-class CIETongueWidgetPriv
+class CIETongueWidget::CIETongueWidgetPriv
 {
 public:
 
@@ -162,6 +162,7 @@ public:
         loadingImageMode     = false;
         loadingImageSucess   = false;
         needUpdatePixmap     = false;
+        uncalibratedColor    = false;
         hMonitorProfile      = 0;
         hXYZProfile          = 0;
         hXFORM               = 0;
@@ -176,6 +177,7 @@ public:
     bool             loadingImageMode;
     bool             loadingImageSucess;
     bool             needUpdatePixmap;
+    bool             uncalibratedColor;
 
     int              xBias;
     int              yBias;
@@ -201,7 +203,7 @@ public:
     MEASUREMENT      Measurement;
 };
 
-CIETongueWidget::CIETongueWidget(int w, int h, QWidget *parent, cmsHPROFILE hMonitor)
+CIETongueWidget::CIETongueWidget(int w, int h, QWidget* parent, cmsHPROFILE hMonitor)
                : QWidget(parent), d(new CIETongueWidgetPriv)
 {
     d->progressTimer = new QTimer(this);
@@ -269,6 +271,7 @@ bool CIETongueWidget::setProfileData(const QByteArray& profileData)
     }
 
     d->loadingImageMode = false;
+    d->uncalibratedColor = false;
 
     d->progressTimer->stop();
     d->needUpdatePixmap = true;
@@ -302,6 +305,9 @@ bool CIETongueWidget::setProfileFromFile(const KUrl& file)
         d->loadingImageSucess   = false;
     }
 
+    d->loadingImageMode  = false;
+    d->uncalibratedColor = false;
+
     d->progressTimer->stop();
     d->needUpdatePixmap = true;
     update();
@@ -359,8 +365,8 @@ void CIETongueWidget::setProfile(cmsHPROFILE hProfile)
     // Get target data stored in profile
 
     ZeroMemory(&(d->Measurement), sizeof(MEASUREMENT));
-    char*  CharTarget;
-    size_t CharTargetSize;
+    char*  CharTarget     = 0;
+    size_t CharTargetSize = 0;
 
     if (cmsTakeCharTargetData(hProfile, &CharTarget, &CharTargetSize))
     {
@@ -446,7 +452,6 @@ void CIETongueWidget::outlineTongue()
 
 void CIETongueWidget::fillTongue()
 {
-
     QImage Img = d->pixmap.toImage();
 
     int x;
@@ -706,6 +711,16 @@ void CIETongueWidget::loadingFailed()
     update();
 }
 
+void CIETongueWidget::uncalibratedColor()
+{
+    d->progressTimer->stop();
+    d->progressCount      = 0;
+    d->loadingImageMode   = false;
+    d->loadingImageSucess = false;
+    d->uncalibratedColor  = true;
+    update();
+}
+
 void CIETongueWidget::updatePixmap()
 {
     d->needUpdatePixmap = false;
@@ -797,7 +812,7 @@ void CIETongueWidget::paintEvent(QPaintEvent*)
         return;
     }
 
-    // No profile data to show.
+    // No profile data to show, or RAW file
 
     if (!d->profileDataAvailable || (!d->loadingImageMode && !d->loadingImageSucess))
     {
@@ -808,9 +823,18 @@ void CIETongueWidget::paintEvent(QPaintEvent*)
 
         p.setPen(pen);
         p.drawRect(0, 0, width(), height());
-        p.setPen(Qt::red);
-        p.drawText(0, 0, width(), height(), Qt::AlignCenter,
-                   i18n("No profile available..."));
+
+        if (d->uncalibratedColor)
+        {
+            p.drawText(0, 0, width(), height(), Qt::AlignCenter,
+                    i18n("Uncalibrated color space"));
+        }
+        else
+        {
+            p.setPen(Qt::red);
+            p.drawText(0, 0, width(), height(), Qt::AlignCenter,
+                    i18n("No profile available..."));
+        }
 
         return;
     }
@@ -823,7 +847,7 @@ void CIETongueWidget::paintEvent(QPaintEvent*)
     p.drawPixmap(0, 0, d->pixmap);
 }
 
-void CIETongueWidget::resizeEvent(QResizeEvent * event)
+void CIETongueWidget::resizeEvent(QResizeEvent* event)
 {
     Q_UNUSED(event);
     d->needUpdatePixmap = true;
