@@ -7,6 +7,7 @@
  * Description : GPS search sidebar tab contents.
  *
  * Copyright (C) 2008-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009 by Johannes Wienke <languitar at semipol dot de>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -30,6 +31,7 @@
 
 // local includes
 
+#include "statesavingobject.h"
 #include "worldmapwidget.h"
 
 class QDragEnterEvent;
@@ -39,31 +41,40 @@ class QPixmap;
 namespace Digikam
 {
 
+class Album;
 class SAlbum;
 class ImageInfo;
 class ImageInfoList;
 class SearchTextBar;
 class GPSSearchFolderView;
 class GPSSearchViewPriv;
+class SearchModel;
+class SearchModificationHelper;
 
-class GPSSearchView : public QWidget
+class GPSSearchView : public QWidget, public StateSavingObject
 {
     Q_OBJECT
 
 public:
 
-    GPSSearchView(QWidget *parent=0);
+    GPSSearchView(QWidget *parent, SearchModel *searchModel,
+                  SearchModificationHelper *searchModificationHelper);
     ~GPSSearchView();
 
-    GPSSearchFolderView* folderView() const;
-    SearchTextBar* searchBar() const;
-
     void setActive(bool val);
 
+    void changeAlbumFromHistory(SAlbum *album);
+
+    virtual void setConfigGroup(KConfigGroup group);
+    void doLoadState();
+    void doSaveState();
+
+public Q_SLOTS:
+    void slotDigikamViewNoCurrentItem();
+    void slotDigikamViewImageSelected(const ImageInfoList &selectedImage, bool hasPrevious, bool hasNext, const ImageInfoList &allImages);
+
 private:
 
-    void readConfig();
-    void writeConfig();
 
     bool checkName(QString& name);
     bool checkAlbum(const QString& name) const;
@@ -72,8 +83,7 @@ private:
 
 private Q_SLOTS:
 
-    void slotAlbumSelected(SAlbum*);
-    void slotRenameAlbum(SAlbum*);
+    void slotAlbumSelected(Album*);
 
     void slotSaveGPSSAlbum();
     void slotCheckNameEditGPSConditions();
@@ -82,9 +92,6 @@ private Q_SLOTS:
 
     void slotItemsInfo(const ImageInfoList&);
     
-    void slotDigikamViewNoCurrentItem();
-    void slotDigikamViewImageSelected(const ImageInfoList &selectedImage, bool hasPrevious, bool hasNext, const ImageInfoList &allImages);
-    
     void slotMapSelectedItems(const GPSInfoList& gpsList);
     void slotMapSoloItems(const GPSInfoList& gpsList);
     
