@@ -7,7 +7,7 @@
  * Description : image editor canvas management class
  *
  * Copyright (C) 2004-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
- * Copyright (C) 2004-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -69,10 +69,10 @@ public:
     Canvas(QWidget *parent=0);
     ~Canvas();
 
-    void    load(const QString& filename, IOFileSettingsContainer *IOFileSettings);
+    void    load(const QString& filename, IOFileSettingsContainer* IOFileSettings);
     void    preload(const QString& filename);
 
-    void    saveAs(const QString& filename, IOFileSettingsContainer *IOFileSettings,
+    void    saveAs(const QString& filename, IOFileSettingsContainer* IOFileSettings,
                    bool setExifOrientationTag, const QString& mimeType=QString());
     void    resetImage();
     void    switchToLastSaved(const QString& newFilename);
@@ -94,7 +94,10 @@ public:
     void   setZoomFactorSnapped(double zoom);
 
     double zoomFactor();
+    double zoomMax();
+    double zoomMin();
     void   setZoomFactor(double z);
+
     void   setFitToWindow(bool enable);
     bool   fitToWindow();
     bool   maxZoom();
@@ -103,6 +106,7 @@ public:
     int    imageWidth();
     int    imageHeight();
     QRect  getSelectedArea();
+    QRect  visibleArea();
 
     // If current image file format is only available in read only,
     // typically all RAW image file formats.
@@ -112,8 +116,8 @@ public:
     void  resizeImage(int w, int h);
 
     void  setBackgroundColor(const QColor& color);
-    void  setICCSettings(ICCSettingsContainer *cmSettings);
-    void  setExposureSettings(ExposureSettingsContainer *expoSettings);
+    void  setICCSettings(ICCSettingsContainer* cmSettings);
+    void  setExposureSettings(ExposureSettingsContainer* expoSettings);
     void  setSoftProofingEnabled(bool enable);
 
     void  setExifOrient(bool exifOrient);
@@ -171,12 +175,13 @@ public Q_SLOTS:
 
 protected:
 
-    void resizeEvent(QResizeEvent* e);
-    void viewportPaintEvent(QPaintEvent *e);
-    void contentsMousePressEvent(QMouseEvent *e);
-    void contentsMouseMoveEvent(QMouseEvent *e);
-    void contentsMouseReleaseEvent(QMouseEvent *e);
-    void contentsWheelEvent(QWheelEvent *e);
+    void resizeEvent(QResizeEvent*);
+    void viewportPaintEvent(QPaintEvent*);
+    void contentsMousePressEvent(QMouseEvent*);
+    void contentsMouseMoveEvent(QMouseEvent*);
+    void contentsMouseReleaseEvent(QMouseEvent*);
+    void contentsWheelEvent(QWheelEvent*);
+    void keyPressEvent(QKeyEvent*);
 
 private:
 
