@@ -1039,7 +1039,7 @@ void EditorWindow::slotToggleFullScreen()
 
         m_canvas->setBackgroundColor(m_bgColor);
 
-        menuBar()->show();
+        slotShowMenuBar();
         statusBar()->show();
         showToolBars();
 
@@ -1340,6 +1340,7 @@ void EditorWindow::slotPrepareToLoad()
 void EditorWindow::slotLoadingStarted(const QString& /*filename*/)
 {
     setCursor(Qt::WaitCursor);
+    toggleActions(false);
     m_animLogo->start();
     m_nameLabel->progressBarMode(StatusProgressBar::ProgressBarMode, i18n("Loading: "));
 }
@@ -2225,8 +2226,7 @@ void EditorWindow::setToolStopProgress()
 
 void EditorWindow::slotShowMenuBar()
 {
-    const bool visible = menuBar()->isVisible();
-    menuBar()->setVisible(!visible);
+    menuBar()->setVisible(d->showMenuBarAction->isChecked());
 }
 
 void EditorWindow::slotCloseTool()
