@@ -114,6 +114,7 @@
 #include "globals.h"
 #include "uifilevalidator.h"
 #include "albummodel.h"
+#include "knotificationwrapper.h"
 
 namespace Digikam
 {
@@ -925,6 +926,10 @@ void ImageWindow::saveIsComplete()
     // notify main app that file changed
     emit signalFileModified(m_savingContext->destinationURL);
 
+    // Pop-up a message to bring user when save is done.
+    KNotificationWrapper("editorsavefilecompleted", i18n("save file is completed..."),
+                         this, windowTitle());
+
     // all that is done in slotLoadCurrent, except for loading
     int index = d->urlList.indexOf(d->urlCurrent);
 
@@ -1018,6 +1023,10 @@ void ImageWindow::saveAsIsComplete()
         d->thumbBar->blockSignals(false);
 
         slotUpdateItemInfo();
+
+        // Pop-up a message to bring user when save is done.
+        KNotificationWrapper("editorsavefilecompleted", i18n("save file is completed..."),
+                             this, windowTitle());
     }
     else
     {
