@@ -6,7 +6,7 @@
  * Date        : 2008-11-28
  * Description : PNG image Converter batch tool.
  *
- * Copyright (C) 2008-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -44,7 +44,7 @@ namespace Digikam
 {
 
 Convert2PNG::Convert2PNG(QObject* parent)
-           : BatchTool("Convert2PNG", BaseTool, parent)
+           : BatchTool("Convert2PNG", ConvertTool, parent)
 {
     setToolTitle(i18n("Convert To PNG"));
     setToolDescription(i18n("A tool to convert images to PNG format."));
@@ -80,7 +80,7 @@ void Convert2PNG::slotSettingsChanged()
 {
     BatchToolSettings settings;
     settings.insert("Quality", m_settings->getCompressionValue());
-    setSettings(settings);
+    BatchTool::slotSettingsChanged(settings);
 }
 
 QString Convert2PNG::outputSuffix() const
