@@ -6,7 +6,7 @@
  * Date        : 2008-11-28
  * Description : PNG image Converter batch tool.
  *
- * Copyright (C) 2008-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -24,7 +24,7 @@
 #ifndef CONVERT2PNG_H
 #define CONVERT2PNG_H
 
-// Local includes.
+// Local includes
 
 #include "batchtool.h"
 
@@ -48,10 +48,10 @@ public:
 private Q_SLOTS:
 
     void slotSettingsChanged();
+    void slotAssignSettings2Widget();
 
 private:
 
-    void assignSettings2Widget();
     bool toolOperations();
 
 private:
