@@ -4,9 +4,10 @@
  * http://www.digikam.org
  *
  * Date        : 2009-05-02
- * Description : image sharpen batch tool.
+ * Description : sharpen image batch tool.
  *
  * Copyright (C) 2009 by Matthias Welwarsky <matze at welwarsky dot de>
+ * Copyright (C) 2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -26,62 +27,34 @@
 
 #include "batchtool.h"
 
-namespace KDcrawIface
-{
-    class RIntNumInput;
-    class RComboBox;
-    class RDoubleNumInput;
-}
-
-class QStackedWidget;
-
 namespace Digikam
 {
 
+class SharpSettings;
+
 class Sharpen : public BatchTool
 {
     Q_OBJECT
 
 public:
 
-    Sharpen(QObject *parent=0);
+    Sharpen(QObject* parent=0);
     ~Sharpen();
 
     BatchToolSettings defaultSettings();
 
 private:
 
-    enum SharpenType
-    {
-        SimpleSharp,
-        UnsharpMask,
-        Refocus
-    };
-
     bool toolOperations();
 
 private Q_SLOTS:
 
     void slotAssignSettings2Widget();
     void slotSettingsChanged();
-    void slotSharpMethodChanged(int);
 
 private:
 
-    QStackedWidget               *m_stack;
-
-    KDcrawIface::RComboBox       *m_sharpMethod;
-	
-	KDcrawIface::RIntNumInput    *m_radiusInput;
-    KDcrawIface::RIntNumInput    *m_radiusInput2;
-    KDcrawIface::RIntNumInput    *m_matrixSize;
-
-    KDcrawIface::RDoubleNumInput *m_radius;
-    KDcrawIface::RDoubleNumInput *m_gauss;
-    KDcrawIface::RDoubleNumInput *m_correlation;
-    KDcrawIface::RDoubleNumInput *m_noise;
-    KDcrawIface::RDoubleNumInput *m_amountInput;
-    KDcrawIface::RDoubleNumInput *m_thresholdInput;
+    SharpSettings* m_settingsView;
 };
 
 } // namespace Digikam
