@@ -792,7 +792,7 @@ int QueueListView::pendingTasksCount()
     {
         QueueListViewItem* item = dynamic_cast<QueueListViewItem*>(*it);
         if (item && !item->isDone())
-            count += assignedTools().toolsMap.count();
+            count += assignedTools().m_toolsMap.count();
         ++it;
     }
     return count;
@@ -853,8 +853,7 @@ void QueueListView::updateDestFileNames()
         ParseSettings psettings;
         psettings.parseString = settings().renamingParser;
 
-        QStringList tmpFiles;
-
+        QList<ParseSettings> files;
         QTreeWidgetItemIterator it(this);
         while (*it)
         {
@@ -865,12 +864,14 @@ void QueueListView::updateDestFileNames()
                 ImageInfo info = item->info();
                 QFileInfo fi(info.filePath());
 
-                tmpFiles << fi.absoluteFilePath();
+                ParseSettings ps;
+                ps.fileUrl = KUrl(fi.absoluteFilePath());
+                files << ps;
             }
             ++it;
         }
 
-        manager.addFiles(tmpFiles);
+        manager.addFiles(files);
         manager.parseFiles(psettings);
         renamingResults = manager.newFileList();
     }
@@ -889,7 +890,7 @@ void QueueListView::updateDestFileNames()
 
             // Update suffix using assigned batch tool rules.
             bool extensionSet = false;
-            tools.itemUrl     = item->info().fileUrl();
+            tools.m_itemUrl   = item->info().fileUrl();
             QString newSuffix = tools.targetSuffix(&extensionSet);
             QString newName   = QString("%1.%2").arg(fi.completeBaseName()).arg(newSuffix);
 
@@ -947,4 +948,9 @@ void QueueListView::slotCollectionImageChange(const CollectionImageChangeset& ch
     }
 }
 
+void QueueListView::reloadThumbs(const KUrl& url)
+{
+    d->thumbLoadThread->find(url.toLocalFile());
+}
+
 }  // namespace Digikam
