@@ -26,6 +26,7 @@
 
 // Qt includes
 
+#include <QDir>
 #include <QFile>
 #include <QFileInfo>
 #include <QTimer>
@@ -66,6 +67,7 @@
 
 // Local includes
 
+#include "album.h"
 #include "drawdecoding.h"
 #include "batchtoolsmanager.h"
 #include "actionthread.h"
@@ -83,7 +85,6 @@
 #include "dmetadata.h"
 #include "albumsettings.h"
 #include "albummanager.h"
-#include "loadingcacheinterface.h"
 #include "imagewindow.h"
 #include "imagedialog.h"
 #include "thumbnailsize.h"
@@ -91,6 +92,7 @@
 #include "sidebar.h"
 #include "uifilevalidator.h"
 #include "knotificationwrapper.h"
+#include "scancontroller.h"
 
 namespace Digikam
 {
@@ -337,11 +339,6 @@ void QueueMgrWindow::setupConnections()
 
     connect(d->toolsView, SIGNAL(signalHistoryEntryClicked(int, qlonglong)),
             this, SLOT(slotHistoryEntryClicked(int, qlonglong)));
-
-    // -- FileWatch connections ------------------------------
-
-    LoadingCacheInterface::connectToSignalFileChanged(this,
-            SLOT(slotFileChanged(const QString &)));
 }
 
 void QueueMgrWindow::setupActions()
@@ -468,11 +465,6 @@ void QueueMgrWindow::setupActions()
     d->showMenuBarAction->setChecked(!menuBar()->isHidden());  // NOTE: workaround for B.K.O #171080
 }
 
-void QueueMgrWindow::slotFileChanged(const QString& /*filePath*/)
-{
-    // TODO
-}
-
 void QueueMgrWindow::refreshView()
 {
     // NOTE: method called when something is changed from Database (tags, rating, etc...).
@@ -621,7 +613,7 @@ void QueueMgrWindow::slotToggleFullScreen()
     {
         setWindowState( windowState() & ~Qt::WindowFullScreen ); // reset
 
-        menuBar()->show();
+        slotShowMenuBar();
         statusBar()->show();
         showToolBars();
 
@@ -792,6 +784,27 @@ void QueueMgrWindow::slotDBStat()
     showDigikamDatabaseStat();
 }
 
+bool QueueMgrWindow::queryClose()
+{
+    if (isBusy())
+    {
+        int result = KMessageBox::warningYesNo(this, 
+                        i18n("Batch Queue Manager is running. Do you want to cancel current job?"),
+                        i18n("Processing under progress"));
+
+        if (result == KMessageBox::Yes)
+        {
+            slotStop();
+        }
+        else if (result == KMessageBox::No)
+        {
+            return false;
+        }
+    }
+
+    return true;
+}
+
 void QueueMgrWindow::addNewQueue()
 {
     d->queuePool->slotAddQueue();
@@ -833,8 +846,7 @@ void QueueMgrWindow::populateToolsList()
 
 void QueueMgrWindow::slotShowMenuBar()
 {
-    const bool visible = menuBar()->isVisible();
-    menuBar()->setVisible(!visible);
+    menuBar()->setVisible(d->showMenuBarAction->isChecked());
 }
 
 void QueueMgrWindow::slotRun()
@@ -898,6 +910,8 @@ void QueueMgrWindow::processingAborted()
 
 void QueueMgrWindow::processOne()
 {
+    d->assignedList->reset();
+
     if (d->itemsList.empty())
     {
         // Pop-up a message to bring user when all is done.
@@ -917,13 +931,13 @@ void QueueMgrWindow::processOne()
 
     QueueSettings settings        = d->queuePool->currentQueue()->settings();
     AssignedBatchTools tools4Item = d->queuePool->currentQueue()->assignedTools();
-    tools4Item.itemUrl            = set.info.fileUrl();
-    QueueListViewItem* item       = d->queuePool->currentQueue()->findItemByUrl(tools4Item.itemUrl);
+    tools4Item.m_itemUrl          = set.info.fileUrl();
+    QueueListViewItem* item       = d->queuePool->currentQueue()->findItemByUrl(tools4Item.m_itemUrl);
     if (item)
     {
         d->itemsList.removeFirst();
 
-        if (!tools4Item.toolsMap.isEmpty())
+        if (!tools4Item.m_toolsMap.isEmpty())
         {
             d->thread->setWorkingUrl(settings.targetUrl);
             d->thread->processFile(tools4Item);
@@ -954,7 +968,7 @@ void QueueMgrWindow::slotAction(const ActionData& ad)
         }
         case ActionData::BatchFailed:
         {
-            processingFailed(ad.fileUrl);
+            processingFailed(ad.fileUrl, ad.message);
             processOne();
             break;
         }
@@ -1015,7 +1029,6 @@ void QueueMgrWindow::slotProgressTimerDone()
 
 void QueueMgrWindow::processing(const KUrl& url)
 {
-    d->assignedList->reset();
     d->currentProcessItem = d->queuePool->currentQueue()->findItemByUrl(url);
     if (d->currentProcessItem)
     {
@@ -1098,19 +1111,32 @@ void QueueMgrWindow::processed(const KUrl& url, const KUrl& tmp)
                 addHistoryMessage(i18n("Item processed successfully..."), DHistoryView::SuccessEntry);
             }
 
-            // TODO: assign attributes from original image.
+            // -- Now copy the digiKam attributes from original file to the new file ------------
+
+            KUrl srcDirURL(QDir::cleanPath(url.directory()));
+            PAlbum* srcAlbum = AlbumManager::instance()->findPAlbum(srcDirURL);
+
+            KUrl dstDirURL(QDir::cleanPath(dest.directory()));
+            PAlbum* dstAlbum = AlbumManager::instance()->findPAlbum(dstDirURL);
+
+            if (dstAlbum && srcAlbum)
+            {
+                ImageInfo oldInfo(url.toLocalFile());
+                ScanController::instance()->scanFileDirectlyCopyAttributes(dest.toLocalFile(), oldInfo.id());
+            }
         }
     }
 
     d->currentProcessItem = 0;
 }
 
-void QueueMgrWindow::processingFailed(const KUrl&)
+void QueueMgrWindow::processingFailed(const KUrl&, const QString& errMsg)
 {
     if (d->currentProcessItem)
     {
         d->currentProcessItem->setCanceled();
         addHistoryMessage(i18n("Failed to process item..."), DHistoryView::ErrorEntry);
+        addHistoryMessage(errMsg, DHistoryView::ErrorEntry);
     }
 
     if (d->currentTaskItem)
@@ -1171,7 +1197,7 @@ void QueueMgrWindow::slotAssignedToolsChanged(const AssignedBatchTools& tools)
         return;
     }
 
-    switch (tools.toolsMap.count())
+    switch (tools.m_toolsMap.count())
     {
         case 0:
         {
@@ -1242,19 +1268,6 @@ void QueueMgrWindow::moveEvent(QMoveEvent* e)
     emit signalWindowHasMoved();
 }
 
-bool QueueMgrWindow::event(QEvent* e)
-{
-    switch (e->type())
-    {
-        case QEvent::WindowDeactivate:
-            emit signalWindowLostFocus();
-            break;
-        default:
-            break;
-    }
-    return KXmlGuiWindow::event(e);
-}
-
 void QueueMgrWindow::addHistoryMessage(const QString& msg, DHistoryView::EntryType type)
 {
     if (d->currentProcessItem)
