@@ -52,13 +52,9 @@ public:
 private:
 
     void readSettings();
-    void checkDBPath();
 
 private Q_SLOTS:
 
-    void slotChangeDatabasePath(const KUrl&);
-    void slotDatabasePathEdited(const QString&);
-
 private:
 
     SetupCollectionsPriv* const d;
