@@ -6,7 +6,7 @@
  * Date        : 2007-02-06
  * Description : setup RAW decoding settings.
  *
- * Copyright (C) 2007-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2007-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -24,11 +24,11 @@
 #ifndef SETUPDCRAW_H
 #define SETUPDCRAW_H
 
-// Qt includes.
+// Qt includes
 
 #include <QScrollArea>
 
-// Local includes.
+// Local includes
 
 #include "digikam_export.h"
 
@@ -53,7 +53,7 @@ private:
     void readSettings();
 
 
-private slots:
+private Q_SLOTS:
 
     void slotSixteenBitsImageToggled(bool);
 
