@@ -25,7 +25,7 @@
 #ifndef SETUPMETADATA_H
 #define SETUPMETADATA_H
 
-// Qt includes.
+// Qt includes
 
 #include <QScrollArea>
 
@@ -51,10 +51,11 @@ private:
 
     void readSettings();
 
-private slots:
+private Q_SLOTS:
 
-    void processExiv2Url(const QString&);
+    void slotProcessExiv2Url(const QString&);
     void slotExifAutoRotateToggled(bool);
+    void slotNepomukToggled();
 
 private:
 
