@@ -6,8 +6,8 @@
  * Date        : 2005-04-21
  * Description : slide show tool using preview of pictures.
  *
- * Copyright (C) 2005-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2004 by Enrico Ros <eros.kde@email.it>                  *
+ * Copyright (C) 2005-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004 by Enrico Ros <eros.kde@email.it>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -24,10 +24,9 @@
 
 #define MAXSTRINGLEN 80
 
-#include "slideshow.h"
 #include "slideshow.moc"
 
-// Qt includes.
+// Qt includes
 
 #include <QColor>
 #include <QCursor>
@@ -45,40 +44,41 @@
 #include <QtDBus/QDBusMessage>
 #include <QtDBus/QDBusReply>
 
-// KDE includes.
+// KDE includes
 
+#include <kaboutdata.h>
 #include <kapplication.h>
-#include <kdebug.h>
 #include <kdeversion.h>
 #include <kdialog.h>
 #include <kglobalsettings.h>
 #include <kiconloader.h>
 #include <klocale.h>
 #include <kstandarddirs.h>
+#include <kdebug.h>
 
-// Local includes.
+// Local includes
 
-#include "constants.h"
 #include "dimg.h"
+#include "globals.h"
 #include "previewloadthread.h"
 #include "toolbar.h"
 
 namespace Digikam
 {
 
-class SlideShowPriv
+class SlideShow::SlideShowPriv
 {
 public:
 
     SlideShowPriv()
     {
-        previewThread  = 0;
-        mouseMoveTimer = 0;
-        timer          = 0;
-        toolBar        = 0;
-        fileIndex      = -1;
-        endOfShow      = false;
-        pause          = false;
+        previewThread     = 0;
+        mouseMoveTimer    = 0;
+        timer             = 0;
+        toolBar           = 0;
+        fileIndex         = -1;
+        endOfShow         = false;
+        pause             = false;
         screenSaverCookie = -1;
 
         // Pre-computed star polygon for a 15x15 pixmap.
@@ -104,8 +104,8 @@ public:
     int                fileIndex;
     int                screenSaverCookie;
 
-    QTimer            *mouseMoveTimer;  // To hide cursor when not moved.
-    QTimer            *timer;
+    QTimer*            mouseMoveTimer;  // To hide cursor when not moved.
+    QTimer*            timer;
 
     QPixmap            pixmap;
     QPixmap            selPixmap;      // Selected rating star.
@@ -117,10 +117,10 @@ public:
 
     KUrl               currentImage;
 
-    PreviewLoadThread *previewThread;
-    PreviewLoadThread *previewPreloadThread;
+    PreviewLoadThread* previewThread;
+    PreviewLoadThread* previewPreloadThread;
 
-    ToolBar           *toolBar;
+    ToolBar*           toolBar;
 
     SlideShowSettings  settings;
 };
@@ -182,8 +182,10 @@ SlideShow::SlideShow(const SlideShowSettings& settings)
     d->timer                = new QTimer(this);
     d->mouseMoveTimer       = new QTimer(this);
 
-    connect(d->previewThread, SIGNAL(signalImageLoaded(const LoadingDescription &, const DImg &)),
-            this, SLOT(slotGotImagePreview(const LoadingDescription &, const DImg&)));
+    d->previewThread->setDisplayingWidget(this);
+    d->previewPreloadThread->setDisplayingWidget(this);
+    connect(d->previewThread, SIGNAL(signalImageLoaded(const LoadingDescription&, const DImg&)),
+            this, SLOT(slotGotImagePreview(const LoadingDescription&, const DImg&)));
 
     connect(d->mouseMoveTimer, SIGNAL(timeout()),
             this, SLOT(slotMouseMoveTimeOut()));
@@ -279,8 +281,8 @@ void SlideShow::loadNextImage()
     if (d->fileIndex < num)
     {
         d->currentImage = d->settings.fileList[d->fileIndex];
-        d->previewThread->load(LoadingDescription(d->currentImage.path(),
-                               qMax(d->deskWidth, d->deskHeight), d->settings.exifRotate));
+        d->previewThread->load(d->currentImage.toLocalFile(),
+                               qMax(d->deskWidth, d->deskHeight), d->settings.exifRotate);
     }
     else
     {
@@ -313,8 +315,8 @@ void SlideShow::loadPrevImage()
     if (d->fileIndex >= 0 && d->fileIndex < num)
     {
         d->currentImage = d->settings.fileList[d->fileIndex];
-        d->previewThread->load(LoadingDescription(d->currentImage.path(),
-                               qMax(d->deskWidth, d->deskHeight), d->settings.exifRotate));
+        d->previewThread->load(d->currentImage.toLocalFile(),
+                               qMax(d->deskWidth, d->deskHeight), d->settings.exifRotate);
     }
     else
     {
@@ -325,9 +327,9 @@ void SlideShow::loadPrevImage()
     }
 }
 
-void SlideShow::slotGotImagePreview(const LoadingDescription &desc, const DImg& preview)
+void SlideShow::slotGotImagePreview(const LoadingDescription& desc, const DImg& preview)
 {
-    if (desc.filePath != d->currentImage.path() || desc.isThumbnail())
+    if (desc.filePath != d->currentImage.toLocalFile() || desc.isThumbnail())
         return;
 
     d->preview = preview;
@@ -361,8 +363,8 @@ void SlideShow::preloadNextImage()
 
     if (index < num)
     {
-        d->previewPreloadThread->load(LoadingDescription(d->settings.fileList[index].path(),
-                                      qMax(d->deskWidth, d->deskHeight), d->settings.exifRotate));
+        d->previewPreloadThread->load(d->settings.fileList[index].toLocalFile(),
+                                      qMax(d->deskWidth, d->deskHeight), d->settings.exifRotate);
     }
 }
 
@@ -372,7 +374,7 @@ void SlideShow::updatePixmap()
     d->pixmap.fill(Qt::black);
     QPainter p(&(d->pixmap));
 
-    if (!d->currentImage.path().isEmpty())
+    if (!d->currentImage.toLocalFile().isEmpty())
     {
         if (!d->preview.isNull())
         {
@@ -385,21 +387,21 @@ void SlideShow::updatePixmap()
 
             QString str;
             PhotoInfoContainer photoInfo = d->settings.pictInfoMap[d->currentImage].photoInfo;
-            int offset = 0;
+            int offset                   = 0;
 
             // Display Rating.
-            int rating = d->settings.pictInfoMap[d->currentImage].rating;
+            int rating                   = d->settings.pictInfoMap[d->currentImage].rating;
 
             if (d->settings.printRating && rating > 0)
             {
                 int x = 0;
-                for (int i = 0; i < rating; i++)
+                for (int i = 0; i < rating; ++i)
                 {
                     p.drawPixmap(10+x, height()-offset-d->selPixmap.height(), d->selPixmap);
                     x += d->selPixmap.width();
                 }
 
-                for (int i = rating; i < RatingMax; i++)
+                for (int i = rating; i < RatingMax; ++i)
                 {
                     p.drawPixmap(10+x, height()-offset-d->regPixmap.height(), d->regPixmap);
                     x += d->regPixmap.width();
@@ -418,7 +420,7 @@ void SlideShow::updatePixmap()
 
             if (d->settings.printMakeModel)
             {
-                str = QString();
+                str.clear();
 
                 if (!photoInfo.make.isEmpty())
                     str = photoInfo.make;
@@ -438,7 +440,7 @@ void SlideShow::updatePixmap()
 
             if (d->settings.printExpoSensitivity)
             {
-                str = QString();
+                str.clear();
 
                 if (!photoInfo.exposureTime.isEmpty())
                     str = photoInfo.exposureTime;
@@ -458,7 +460,7 @@ void SlideShow::updatePixmap()
 
             if (d->settings.printApertureFocal)
             {
-                str = QString();
+                str.clear();
 
                 if (!photoInfo.aperture.isEmpty())
                     str = photoInfo.aperture;
@@ -524,8 +526,17 @@ void SlideShow::updatePixmap()
     {
         // End of Slide Show.
 
-        QPixmap logo = QPixmap(KStandardDirs::locate("data", "digikam/data/logo-digikam.png"))
-                               .scaled(128, 128, Qt::KeepAspectRatio, Qt::SmoothTransformation);
+        QPixmap logo;
+        if (KGlobal::mainComponent().aboutData()->appName() == QString("digikam"))
+        {
+            logo = QPixmap(KStandardDirs::locate("data", "digikam/data/logo-digikam.png"))
+                           .scaled(128, 128, Qt::KeepAspectRatio, Qt::SmoothTransformation);
+        }
+        else
+        {
+            logo = QPixmap(KStandardDirs::locate("data", "showfoto/data/logo-showfoto.png"))
+                           .scaled(128, 128, Qt::KeepAspectRatio, Qt::SmoothTransformation);
+        }
 
         QFont fn(font());
         fn.setPointSize(fn.pointSize()+10);
@@ -544,14 +555,14 @@ void SlideShow::updatePixmap()
     }
 }
 
-void SlideShow::printInfoText(QPainter &p, int &offset, const QString& str)
+void SlideShow::printInfoText(QPainter& p, int& offset, const QString& str)
 {
     if (!str.isEmpty())
     {
         offset += 20;
         p.setPen(Qt::black);
-        for (int x=9; x<=11; x++)
-            for (int y=offset+1; y>=offset-1; y--)
+        for (int x=9; x<=11; ++x)
+            for (int y=offset+1; y>=offset-1; --y)
                 p.drawText(x, height()-y, str);
 
         p.setPen(Qt::white);
@@ -559,7 +570,7 @@ void SlideShow::printInfoText(QPainter &p, int &offset, const QString& str)
     }
 }
 
-void SlideShow::printComments(QPainter &p, int &offset, const QString& comments)
+void SlideShow::printComments(QPainter& p, int& offset, const QString& comments)
 {
     QStringList commentsByLines;
 
@@ -576,9 +587,9 @@ void SlideShow::printComments(QPainter &p, int &offset, const QString& comments)
         uint commentsLinesLengthLocal = MAXSTRINGLEN;
 
         for (currIndex = commentsIndex ;
-             currIndex < (uint)comments.length() && !breakLine ; currIndex++ )
+             currIndex < (uint)comments.length() && !breakLine ; ++currIndex )
         {
-            if( comments[currIndex] == QChar('\n') || comments[currIndex].isSpace() )
+            if ( comments[currIndex] == QChar('\n') || comments[currIndex].isSpace() )
                 breakLine = true;
         }
 
@@ -590,7 +601,7 @@ void SlideShow::printComments(QPainter &p, int &offset, const QString& comments)
         for (currIndex = commentsIndex ;
              currIndex <= commentsIndex + commentsLinesLengthLocal &&
              currIndex < (uint)comments.length() && !breakLine ;
-             currIndex++ )
+             ++currIndex )
             {
                 breakLine = (comments[currIndex] == QChar('\n')) ? true : false;
 
@@ -607,20 +618,20 @@ void SlideShow::printComments(QPainter &p, int &offset, const QString& comments)
             while (!newLine.endsWith(' '))
             {
                 newLine.truncate(newLine.length() - 1);
-                commentsIndex--;
+                --commentsIndex;
             }
         }
 
         commentsByLines.prepend(newLine.trimmed());
     }
 
-    for (int i = 0 ; i < (int)commentsByLines.count() ; i++ )
+    for (int i = 0 ; i < (int)commentsByLines.count() ; ++i )
     {
         printInfoText(p, offset, commentsByLines[i]);
     }
 }
 
-void SlideShow::paintEvent(QPaintEvent *)
+void SlideShow::paintEvent(QPaintEvent*)
 {
     QPainter p(this);
     p.drawPixmap(0, 0, d->pixmap,
@@ -643,9 +654,9 @@ void SlideShow::slotPause()
 
 void SlideShow::slotPlay()
 {
+    d->timer->start();
     d->toolBar->hide();
     d->pause = false;
-    slotTimeOut();
 }
 
 void SlideShow::slotPrev()
@@ -663,7 +674,7 @@ void SlideShow::slotClose()
     close();
 }
 
-void SlideShow::wheelEvent(QWheelEvent * e)
+void SlideShow::wheelEvent(QWheelEvent *e)
 {
     if (e->delta() < 0)
     {
@@ -682,7 +693,7 @@ void SlideShow::wheelEvent(QWheelEvent * e)
     }
 }
 
-void SlideShow::mousePressEvent(QMouseEvent *e)
+void SlideShow::mousePressEvent(QMouseEvent* e)
 {
     if (d->endOfShow)
         close();
@@ -703,34 +714,38 @@ void SlideShow::mousePressEvent(QMouseEvent *e)
     }
 }
 
-void SlideShow::keyPressEvent(QKeyEvent *event)
+void SlideShow::keyPressEvent(QKeyEvent* e)
 {
-    if (!event)
+    if (!e)
         return;
 
-    d->toolBar->keyPressEvent(event);
+    d->toolBar->keyPressEvent(e);
 }
 
-static void makeCornerRectangles(const QRect &desktopRect, const QSize &size,
-                                 QRect *topLeft, QRect *topRight, QRect *bottomLeft, QRect *bottomRight,
-                                 QRect *topLeftLarger, QRect *topRightLarger, QRect *bottomLeftLarger, QRect *bottomRightLarger)
+void SlideShow::makeCornerRectangles(const QRect& desktopRect, const QSize& size,
+                                     QRect* topLeft, QRect* topRight, QRect* bottomLeft, QRect* bottomRight,
+                                     QRect* topLeftLarger, QRect* topRightLarger, QRect* bottomLeftLarger,
+                                     QRect* bottomRightLarger)
 {
-    QRect sizeRect(QPoint(0,0), size);
-    *topLeft = sizeRect; *topRight = sizeRect; *bottomLeft = sizeRect; *bottomRight = sizeRect;
+    QRect sizeRect(QPoint(0, 0), size);
+    *topLeft     = sizeRect;
+    *topRight    = sizeRect;
+    *bottomLeft  = sizeRect;
+    *bottomRight = sizeRect;
 
     topLeft->moveTo(desktopRect.x(), desktopRect.y());
     topRight->moveTo(desktopRect.x() + desktopRect.width() - sizeRect.width() - 1, topLeft->y());
     bottomLeft->moveTo(topLeft->x(), desktopRect.y() + desktopRect.height() - sizeRect.height() - 1);
     bottomRight->moveTo(topRight->x(), bottomLeft->y());
 
-    const int marginX = 25, marginY = 10;
+    const int marginX  = 25, marginY = 10;
     *topLeftLarger     = topLeft->adjusted(0, 0, marginX, marginY);
     *topRightLarger    = topRight->adjusted(-marginX, 0, 0, marginY);
     *bottomLeftLarger  = bottomLeft->adjusted(0, -marginY, marginX, 0);
     *bottomRightLarger = bottomRight->adjusted(-marginX, -marginY, 0, 0);
 }
 
-void SlideShow::mouseMoveEvent(QMouseEvent *e)
+void SlideShow::mouseMoveEvent(QMouseEvent* e)
 {
     setCursor(QCursor(Qt::ArrowCursor));
     d->mouseMoveTimer->setSingleShot(true);
@@ -798,7 +813,7 @@ void SlideShow::inhibitScreenSaver()
 {
     QDBusMessage message = QDBusMessage::createMethodCall( "org.freedesktop.ScreenSaver", "/ScreenSaver",
                                                            "org.freedesktop.ScreenSaver", "Inhibit" );
-    message << QString( "Okular" );
+    message << QString( "digiKam" );
     message << i18nc( "Reason for inhibiting the screensaver activation, when the presentation mode is active", "Giving a presentation" );
 
     QDBusReply<uint> reply = QDBusConnection::sessionBus().call( message );
