@@ -7,7 +7,7 @@
  * Description : a tool bar for slideshow
  *
  * Copyright (C) 2004-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
- * Copyright (C) 2006-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -39,7 +39,7 @@
 namespace Digikam
 {
 
-class ToolBarPriv
+class ToolBar::ToolBarPriv
 {
 public:
 
@@ -172,9 +172,9 @@ void ToolBar::slotNexPrevClicked()
     }
 }
 
-void ToolBar::keyPressEvent(QKeyEvent *event)
+void ToolBar::keyPressEvent(QKeyEvent* e)
 {
-    switch(event->key())
+    switch(e->key())
     {
         case(Qt::Key_Space):
         {
@@ -204,7 +204,7 @@ void ToolBar::keyPressEvent(QKeyEvent *event)
             break;
     }
 
-    event->accept();
+    e->accept();
 }
 
 }   // namespace Digikam
